@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -193,31 +193,31 @@ def get_mode_captions(spectroscopy_specifications):
 
     if ('Vib modes: 1/m' in spectroscopy_specifications):
         mode_caption = 'Wavenumber 1/m'
-        latex_mode_caption = r'$\bar{v}/ (\mathrm{m}^{-1})$'
+        latex_mode_caption = r'$\bar{v} \; / \; (\mathrm{m}^{-1})$'
         mode_header_sting = '%18s'
         mode_format_string = '%19.6f'
         mode_std_format = '%4.0f'
     elif ('Vib modes: 1/cm' in spectroscopy_specifications):
         mode_caption = 'Wavenumber 1/cm'
-        latex_mode_caption = r'$\bar{v} / (\mathrm{cm}^{-1})$'
+        latex_mode_caption = r'$\bar{v} \; / \; (\mathrm{cm}^{-1})$'
         mode_header_sting = '%18s'
         mode_format_string = '%19.6f'
         mode_std_format = '%6.3f'
     elif ('Vib modes: 1/s' in spectroscopy_specifications):
         mode_caption = 'Frequency 1/s'
-        latex_mode_caption = r'$v / (\mathrm{s}^{-1})$'
+        latex_mode_caption = r'$v \; / \; (\mathrm{s}^{-1})$'
         mode_header_sting = '%17s'
         mode_format_string = '%20.9E'
         mode_std_format = '%6.3E'
     elif ('Vib modes: ang. 1/s' in spectroscopy_specifications):
         mode_caption = 'Angular frequency 1/s'
-        latex_mode_caption = r'$\omega / (\mathrm{s}^{-1})$'
+        latex_mode_caption = r'$\omega \; / \; (\mathrm{s}^{-1})$'
         mode_header_sting = '%24s'
         mode_format_string = '%25.9E'
         mode_std_format = '%6.3E'
     elif ('Vib modes: Eh' in spectroscopy_specifications):
         mode_caption = 'Vib energy Eh'
-        latex_mode_caption = r'$E / (\mathrm{E}_h)$'
+        latex_mode_caption = r'$E \; / \; (\mathrm{E}_h)$'
         mode_header_sting = '%17s'
         mode_format_string = '%20.9E'
         mode_std_format = '%6.3E'
@@ -235,49 +235,49 @@ def get_ir_captions(spectroscopy_specifications):
     if ('IR: SSDG, a.u.' in spectroscopy_specifications):
         IR_caption = 'IR SSDG a.u'
         IR_plot_caption = IR_caption
-        latex_ir_caption = r'$\bar{\mu}_g / (a.u.)$'
+        latex_ir_caption = r'$\bar{\mu}_g \; / \; (a.u.)$'
         header_format_string = ' %15s'
         format_string = '%20.10E'
         ir_std_format = '%6.3E'
     elif ('IR: SSDG, C**2/kg' in spectroscopy_specifications):
         IR_caption = 'IR SSDG C²/kg'
         IR_plot_caption = IR_caption
-        latex_ir_caption = r'$\bar{\mu}_g / (\mathrm{C}^2\cdot \mathrm{kg}^{-1})$'
+        latex_ir_caption = r'$\bar{\mu}_g \; / \; (\mathrm{C}^2\cdot \mathrm{kg}^{-1})$'
         header_format_string = '%16s'
         format_string = '%20.10E'
         ir_std_format = '%6.3E'
     elif ('IR: SSDG, D2A2/amu' in spectroscopy_specifications):
         IR_caption = 'IR SSDG (D/Å)²/amu'
         IR_plot_caption = IR_caption
-        latex_ir_caption = r'$\bar{\mu}_g / ((\mathrm{D}/\mathrm{Å})^2\cdot \mathrm{amu}^{-1})$'
+        latex_ir_caption = r'$\bar{\mu}_g \; / \; ((\mathrm{D}/\mathrm{Å})^2\cdot \mathrm{amu}^{-1})$'
         header_format_string = '%20s'
         format_string = '%17.10f'
         ir_std_format = '%6.4f'
     elif ('IR: MDAC, m**2/(s*mol)' in spectroscopy_specifications):
         IR_caption = 'IR MDAC m²/(s*mol)'
         IR_plot_caption = 'IR MDAC m²/mol'
-        latex_ir_caption = r'$\varepsilon / (\mathrm{m}^2\cdot \mathrm{mol}^{-1})$'
+        latex_ir_caption = r'$\varepsilon \; / \; (\mathrm{m}^2\cdot \mathrm{mol}^{-1})$'
         header_format_string = '%22s'
         format_string = '%20.10E'
         ir_std_format = '%6.3E'
     elif ('IR: MDAC, L/(cm*s*mol)' in spectroscopy_specifications):
         IR_caption = 'IR MDAC L/(s*cm*mol)'
         IR_plot_caption = 'IR MDAC L/(cm*mol)'
-        latex_ir_caption = r'$\varepsilon / (\mathrm{L}\cdot \mathrm{cm}^{-1}\mathrm{mol}^{-1})$'
+        latex_ir_caption = r'$\varepsilon \; / \; (\mathrm{L}\cdot \mathrm{cm}^{-1}\mathrm{mol}^{-1})$'
         header_format_string = '%24s'
         format_string = '%22.10E'
         ir_std_format = '%6.3E'
     elif ('IR: NIMAC, m/mol' in spectroscopy_specifications):
         IR_caption = 'IR NIMAC m/mol'
         IR_plot_caption = IR_caption
-        latex_ir_caption = r'$A / (\mathrm{m}\cdot \mathrm{mol}^{-1})$'
+        latex_ir_caption = r'$A \; / \; (\mathrm{m}\cdot \mathrm{mol}^{-1})$'
         header_format_string = '%16s'
         format_string = '%17.8f'
         ir_std_format = '%6.0f'
     elif ('IR: NIMAC, km/mol' in spectroscopy_specifications):
         IR_caption = 'IR NIMAC km/mol'
         IR_plot_caption = IR_caption
-        latex_ir_caption = r'$A / (\mathrm{km}\cdot \mathrm{mol}^{-1})$'
+        latex_ir_caption = r'$A \; / \; (\mathrm{km}\cdot \mathrm{mol}^{-1})$'
         header_format_string = '%18s'
         format_string = '%17.10f'
         ir_std_format = '%6.3f'
@@ -305,19 +305,19 @@ def get_raman_captions(spectroscopy_specifications):
     elif ('Raman: PCPG 45+4, Å^4/amu' in spectroscopy_specifications):
         raman_caption = 'Raman: PCPG 45+4 Å^4/amu'
         raman_plot_caption = 'Raman: PCPG 45+4 Å^4*s/amu'
-        latex_raman_caption = r'$\dfrag{\partial \sigma}{\partial \Omega} \; / \; (\mathrm{Å}^{4}\mathrm{s}\\mathrm{amu}^{-1})$'
+        latex_raman_caption = r'$\sigma_{45+4}^{\prime} \; / \; (\mathrm{Å}^{4}\mathrm{s}\mathrm{amu}^{-1})$'
     elif ('Raman: PCPG 45+7, Å^4/amu' in spectroscopy_specifications):
         raman_caption = 'Raman: PCPG 45+7 Å^4/amu'
         raman_plot_caption = 'Raman: PCPG 45+7 Å^4*s/amu'
-        latex_raman_caption = r'$\dfrac{\partial \sigma}{\partial \Omega} \; / \; (\mathrm{Å}^{4}\mathrm{s}\mathrm{amu}^{-1})$'
+        latex_raman_caption = r'$\sigma_{45+7}^{\prime} \; / \; (\mathrm{Å}^{4}\mathrm{s}\mathrm{amu}^{-1})$'
     elif ('Raman: SCS 45+4, SI units' in spectroscopy_specifications):
         raman_caption = 'Raman: SCS 45+4 C^4*s^2/(J*m^2*kg)'
         raman_plot_caption = 'Raman: SCS 45+4 C^4*s^3/(J*m^2*kg)'
-        latex_raman_caption = r'$\dfrac{\partial sigma}{\partial \Omega} \; / \; (\mathrm{C}^{4}\mathrm{s}^3\mathrm{J}^{-1}\mathrm{m}^{-2}\mathrm{kg}^{-1})$'
+        latex_raman_caption = r'$\sigma_{45+4}^{\prime} \; / \; (\mathrm{C}^{4}\mathrm{s}^3\mathrm{J}^{-1}\mathrm{m}^{-2}\mathrm{kg}^{-1})$'
     elif ('Raman: SCS 45+7, SI units' in spectroscopy_specifications):
         raman_caption = 'Raman: SCS 45+7 C^4*s^2/(J*m^2*kg)'
         raman_plot_caption = 'Raman: SCS 45+7 C^4*s^3/(J*m^2*kg)'
-        latex_raman_caption = r'$\dfrac{\partial \sigma}{\partial \Omega} \; / \; (\mathrm{C}^{4}\mathrm{s}^3\mathrm{J}^{-1}\mathrm{m}^{-2}\mathrm{kg}^{-1})$'
+        latex_raman_caption = r'$\sigma_{45+7}^{\prime} \; / \; (\mathrm{C}^{4}\mathrm{s}^3\mathrm{J}^{-1}\mathrm{m}^{-2}\mathrm{kg}^{-1})$'
     else:
         print('\n')
         print('Error in get_raman_captions')
@@ -329,20 +329,33 @@ def get_raman_captions(spectroscopy_specifications):
 
 def get_hR_captions(spectroscopy_specifications):
     if ('Hyper-Raman: SI complete' in spectroscopy_specifications):
-        vv_hR_caption = 'VV polarized Hyper-Raman: SI complete'
-        hv_hR_caption = 'HV polarized Hyper-Raman: SI complete'
-        hR_caption = 'Hyper-Raman: SI complete'
+        vv_hR_caption = 'VV polarized Hyper-Raman: C^6*s^2/(J*kg^3)'
+        hv_hR_caption = 'HV polarized Hyper-Raman: C^6*s^2/(J*kg^3)'
+        vv_hR_plot_caption = 'Hyper-Raman VV: C^6*s^3/(J*kg^3)'
+        hv_hR_plot_caption = 'Hyper-Raman HV: C^6*s^3/(J*kg^3)'
+        vv_hR_latex = r'$\sigma^{VV} \; / \; (\mathrm{C}^6 \cdot \mathrm{s}^3 \cdot \mathrm{J}^{-1} \cdot \mathrm{kg}^{-3})$'
+        hv_hR_latex = r'$\sigma^{HV} \; / \; (\mathrm{C}^6 \cdot \mathrm{s}^3 \cdot \mathrm{J}^{-1} \cdot \mathrm{kg}^{-3})$'
+        hR_caption = 'Hyper-Raman: C^6*s^2/(J*kg^3)'
+        hR_plot_caption = 'Hyper-Raman: C^6*s^3/(J*kg^3)'
+        hR_latex = r'$\sigma \; / \; (\mathrm{C}^6 \cdot \mathrm{s}^3 \cdot \mathrm{J}^{-1} \cdot \mathrm{kg}^{-3})$'
     elif ('Hyper-Raman: Relative' in spectroscopy_specifications):
         vv_hR_caption = 'VV polarized Hyper-Raman: Relative'
         hv_hR_caption = 'HV polarized Hyper-Raman: Relative'
+        vv_hR_plot_caption = 'Hyper-Raman VV: Relative'
+        hv_hR_plot_caption = 'Hyper-Raman HV: Relative'
+        vv_hR_latex = r'$\sigma^{VV} \; / \; $ (Relative)'
+        hv_hR_latex = r'$\sigma^{HV} \; / \; $ (Relative)'
         hR_caption = 'Hyper-Raman: Relative'
+        hR_plot_caption = 'Hyper-Raman: Relative'
+        hR_latex = r'$\sigma \; / \; $ (Relative)'
     else:
         print('\n')
         print('Error in get_hR_captions')
         print('You forgot to specify the hyper-Raman units in spectroscopy_specifications')
         exit()
 
-    return vv_hR_caption, hv_hR_caption, hR_caption
+    return vv_hR_caption, hv_hR_caption, vv_hR_plot_caption, hv_hR_plot_caption, vv_hR_latex, \
+           hv_hR_latex, hR_caption, hR_plot_caption, hR_latex
 
 
 def get_cauchy_prefactor(spectroscopy_specifications):
