@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -25,7 +25,8 @@ from sys import exit
 
 # File location MUST contain a backslash at the end
 def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specifications, \
-                    cauchy_type, names, spectral_boundaries, print_level, temperature):
+                    cauchy_type, names, harmonic_frequency_limits, spectral_boundaries, \
+                    print_level, temperature, ticker_distance):
 
     # run_specification is set up as follow
     # A) Is it at single or multiple snapshots? => 'Single snapshot', 'Multiple snapshots'
@@ -33,7 +34,7 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
     #    'Plot Raman separately', 'Plot IR and all Raman together', 'Plot Raman together',
     #    'Plot IR and individual Raman together', 'Plot all Hyper-Raman separately',
     #    'Plot Hyper-Raman VV and HV separately' or 'Plot all Hyper-Raman together'.  Otherwise no 
-    #     plots will be created
+    #    plots will be created
     # C) 'FraME' or 'No FraME'
     # D) 'Outproj' or 'No outproj'
     # E) 'Symbolic labels' or nothing
@@ -58,6 +59,8 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
     # 'Raman: PCPG 45+4, Å^4/amu', 'Raman: PCPG 45+7, Å^4/amu', 'Raman: SCS 45+4, SI units'
     # 'Raman: SCS 45+7, SI units'
 
+    # Mandatory options for Hyper-Raman: 'Hyper-Raman: SI complete', 'Hyper-Raman: Relative'
+
     # cauchy_type specifies what type of Cauchy distribution you want, fixed gamma or width made 
     # from the distribution of the snapshots. For fixed gamma, insert 'GS' (this gives 
     # 0.001*max(wavenumber)) or the value that you wish.  For width determined gamma, insert 'WS'.  
@@ -80,8 +83,18 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
     #    5) json name base.  If FraME not used, write 'No FraME'
     #    6) list of any snapshots you wish to ship, f.eks [4, 48]
 
+    # harmonic_frequency_limits specify cut-off of harmonic frequencies.  When running calculations 
+    # with solvent, some lower-frequency modes might be seen as contaminated by translation and 
+    # rotation.  These should therefore be removed so as not to confuse your results and to not 
+    # enter into seemingly higher-frequency overtones and combination bands.  If you wish to keep 
+    # all modes, choose 'Keep all', otherwise specify [min_x, max_x].  In the latter case, make sure 
+    # that you choose a max_x value higher than you highest frequency when performing anharmonic 
+    # calculations.  Otherwise you might up severely changing the anharmonic corrected results, also 
+    # for modes that you have not chosen to remove.
+
     # spectral_boundaries specifies the boundary of the x-axis.  If you wish to plot the whole 
-    # spectrum, choose 'Keep all', otherwise specify [min_freq, max_freq]
+    # spectrum, choose 'Keep all', otherwise specify [min_freq, max_freq].  Note that the values
+    # you put here are in your chosen frequency unit.
 
     # print_level is a number, where 0 is default.
     # A higher number indicates a higher degree of prints, a negative number means less
@@ -171,9 +184,9 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
         elif ('Raman: PCPG 45+7, Å^4/amu' in spectroscopy_specifications):
             print('    Raman pseudo combined polarizability gradients, 45 + 7 combination rule, Å^4/amu')
         elif ('Raman: SCS 45+4, SI units' in spectroscopy_specifications):
-            print('    Absolute differential Raman scattering cross section, 45 + 4 combination rule, SI arbitrary units')
+            print('    Absolute differential Raman scattering cross section, 45 + 4 combination rule, SI units')
         elif ('Raman: SCS 45+7, SI units' in spectroscopy_specifications):
-            print('    Absolute differential Raman scattering cross section, 45 + 7 combination rule, SI arbitrary units')
+            print('    Absolute differential Raman scattering cross section, 45 + 7 combination rule, SI units')
         else:
             print('\n')
             print('Error in SpectroscPy_run')
@@ -255,6 +268,8 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
         anharmonic = False
         anharmonic_type = False
 
+    dangerous_modes = []
+
     for i in range(range_snapshots):
         if (num_snapshots == 1):
             tensor_location = names[0] + names[1]
@@ -289,7 +304,7 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                                                                  spectroscopy_types, \
                                                                  spectroscopy_specifications, \
                                                                  print_level, temperature, \
-                                                                 outproj, anharmonic_type)
+                                                                 outproj, anharmonic_type, harmonic_frequency_limits)
 
         if (i == 0):
             num_modes = len(properties.frequencies.harmonic)
@@ -301,6 +316,10 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                 print('Do all the rsp_tensor files belong to the same molecule?')
                 exit()
 
+        for j in range(num_modes):
+            if ((properties.frequencies.harmonic[j] == 0.0 or properties.frequencies.harmonic[j].imag != 0.0) and not i in dangerous_modes):
+                dangerous_modes.append(j)
+
         all_frequencies.harmonic.append(properties.frequencies.harmonic)
         if (anharmonic):
             all_frequencies.fundamental.append(properties.frequencies.fundamental)
@@ -376,6 +395,13 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                     all_hR_vv_intensities.combotones[j].append(properties.hyper_raman_vv.combotones[j])
                     all_hR_hv_intensities.combotones[j].append(properties.hyper_raman_hv.combotones[j])
 
+    if (dangerous_modes != []):
+        print('DANGEROUS MODES')
+        print('The following modes have frequencies that are either zero or have nonzero imaginary')
+        print('parts.  Use of any of these frequencies or intensities should be done with caution.')
+        for i in range(len(dangerous_modes)):
+            print(dangerous_modes[i])
+
     # AVERAGED VAULES PRINTING PART
     average_harmonic_frequencies = average_over_snapshots(all_frequencies.harmonic)
     if (anharmonic):
@@ -533,7 +559,18 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
             raman_y_label = raman_plot_caption
 
     if ('Hyper-Raman' in spectroscopy_types):
-        vv_hR_caption, hv_hR_caption, hR_caption = get_hR_captions(spectroscopy_specifications)
+        vv_hR_caption, hv_hR_caption, vv_hR_plot_caption, hv_hR_plot_caption, vv_hR_latex, \
+            hv_hR_latex, hR_caption, hR_plot_caption, hR_latex = \
+                get_hR_captions(spectroscopy_specifications)
+
+        if ('Symbolic labels' in run_specification):
+            vv_hR_y_label = vv_hR_latex
+            hv_hR_y_label = hv_hR_latex
+            hR_y_label = hR_latex
+        else:
+            vv_hR_y_label = vv_hR_plot_caption
+            hv_hR_y_label = hv_hR_plot_caption
+            hR_y_label = hR_plot_caption
 
     print('\n')
     print('***************************************************************************************')
@@ -763,7 +800,7 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                 print('\n')
 
         else:
-            print(('%4s' + mode_header_sting + '%43s') %('Mode', mode_caption, vv_hR_caption))
+            print(('%4s' + mode_header_sting + '%55s') %('Mode', mode_caption, vv_hR_caption))
             print('%20s' %(' '), '\t'.join(['%20s %3.2E' % ('Input waven: ', val) for val in \
                                         properties.input_hyperraman_frequencies]))
             for i in range(num_modes):
@@ -774,7 +811,7 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
 
             print('\n')
 
-            print(('%4s' + mode_header_sting + '%43s') %('Mode', mode_caption, hv_hR_caption))
+            print(('%4s' + mode_header_sting + '%55s') %('Mode', mode_caption, hv_hR_caption))
             print('%20s' %(' '), '\t'.join(['%20s %3.2E' % ('Input waven: ', val) for val in \
                                         properties.input_hyperraman_frequencies]))
             for i in range(num_modes):
@@ -822,10 +859,9 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                 or 'Plot IR and individual Raman together' == plot_commands[i]):
 
                 spectrum_file = names[0] + 'anharmonic_ir.png'
-                avg_wavenumbers, avg_intensities = \
-                    anharmonic_visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                                  all_frequencies, all_ir_intensities, x_label, \
-                                                  ir_y_label, spectrum_file, spectral_boundaries)
+                anharmonic_visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                                              all_frequencies, all_ir_intensities, x_label, \
+                                              ir_y_label, spectrum_file, spectral_boundaries, ticker_distance)
 
             if ('Plot Raman separately' == plot_commands[i] or \
                 'Plot Raman together' == plot_commands[i] \
@@ -841,11 +877,10 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                                            all_raman_intensities.fundamental[j], \
                                            all_raman_intensities.overtones[j], \
                                            all_raman_intensities.combotones[j])
-                    avg_wavenumbers, avg_intensities = \
-                        anharmonic_visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                                      all_frequencies, curr_raman_intensities, \
-                                                      x_label, raman_y_label, spectrum_file, \
-                                                      spectral_boundaries)
+                    anharmonic_visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                                                  all_frequencies, curr_raman_intensities, \
+                                                  x_label, raman_y_label, spectrum_file, \
+                                                  spectral_boundaries, ticker_distance)
 
             if ('Plot all Hyper-Raman separately' == plot_commands[i] or \
                 'Plot Hyper-Raman VV and HV separately' == plot_commands[i] or \
@@ -862,11 +897,10 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                                            all_hR_vv_intensities.fundamental[j], \
                                            all_hR_vv_intensities.overtones[j], \
                                            all_hR_vv_intensities.combotones[j])
-                    avg_wavenumbers, avg_intensities = \
-                        anharmonic_visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                                      all_frequencies, curr_raman_intensities, \
-                                                      x_label, vv_hR_caption, spectrum_file, \
-                                                      spectral_boundaries)
+                    anharmonic_visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                                                  all_frequencies, curr_raman_intensities, \
+                                                  x_label, vv_hR_caption, spectrum_file, \
+                                                  spectral_boundaries, ticker_distance)
                     # HV
                     spectrum_file = \
                         names[0] + 'anharmonic_hyperraman_hv_' + \
@@ -877,11 +911,10 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                                            all_hR_hv_intensities.fundamental[j], \
                                            all_hR_hv_intensities.overtones[j], \
                                            all_hR_hv_intensities.combotones[j])
-                    avg_wavenumbers, avg_intensities = \
-                        anharmonic_visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                                      all_frequencies, curr_raman_intensities, \
-                                                      x_label, hv_hR_caption, spectrum_file, \
-                                                      spectral_boundaries)
+                    anharmonic_visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                                                  all_frequencies, curr_raman_intensities, \
+                                                  x_label, hv_hR_caption, spectrum_file, \
+                                                  spectral_boundaries, ticker_distance)
 
         if (('Plot IR' == plot_commands[i]) or \
             ('Plot IR and all Raman together' == plot_commands[i]) or \
@@ -951,13 +984,9 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                     plotting_info = ['all one type']
                     y_label = raman_y_label
 
-            avg_wavenumbers, avg_intensities = visualize_spectrum(cauchy_type_or_value, \
-                                                                  cauchy_prefactor, \
-                                                                  all_frequencies.harmonic, \
-                                                                  all_intensities, x_label, \
-                                                                  y_label, legends, spectrum_file, \
-                                                                  spectral_boundaries, \
-                                                                  plotting_info)
+            visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, all_frequencies.harmonic, \
+                               all_intensities, x_label, y_label, legends, spectrum_file, \
+                               spectral_boundaries, plotting_info, ticker_distance)
 
 
         if (('Plot IR and individual Raman together' == plot_commands[i]) or \
@@ -1012,78 +1041,65 @@ def SpectroscPy_run(run_specification, spectroscopy_types, spectroscopy_specific
                     legends = 0
 
                 plotting_info = []
-                avg_wavenumbers, avg_intensities = visualize_spectrum(cauchy_type_or_value, \
-                                                                      cauchy_prefactor, \
-                                                                      all_frequencies.harmonic, \
-                                                                      all_intensities, \
-                                                                      x_label,  y_label, \
-                                                                      legends, spectrum_file, \
-                                                                      spectral_boundaries, \
-                                                                      plotting_info)
+                visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                                   all_frequencies.harmonic, all_intensities, x_label,  y_label, \
+                                   legends, spectrum_file, spectral_boundaries, plotting_info, ticker_distance)
 
         if ('Plot all Hyper-Raman separately' == plot_commands[i]):
 
             for j in range(num_hyperraman_configs):
-                tmp_y_label = 'Hyper-Raman VV freq. ' + \
-                    str(('%4.1E' %properties.input_hyperraman_frequencies[j]))
+                print('Input frequency: ', '%4.1E' %properties.input_hyperraman_frequencies[j])
+                tmp_y_label = vv_hR_y_label
                 tmp_name = 'hyperraman_vv_freq_' + \
                     str(('%4.1E' %properties.input_hyperraman_frequencies[j])) + '.svg'
 
-                avg_wavenumbers, avg_intensities = \
-                    visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                       all_frequencies.harmonic, \
-                                       [all_hR_vv_intensities.harmonic[j]], x_label, \
-                                       [tmp_y_label], [], tmp_name, spectral_boundaries, [])
+                visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                                   all_frequencies.harmonic, [all_hR_vv_intensities.harmonic[j]], \
+                                   x_label, [tmp_y_label], [], tmp_name, spectral_boundaries, [], ticker_distance)
 
-                tmp_y_label = 'Hyper-Raman HV freq. ' + \
-                    str(('%4.1E' %properties.input_hyperraman_frequencies[j]))
+                tmp_y_label = hv_hR_y_label
                 tmp_name = 'hyperraman_hv_freq_' + \
                     str(('%4.1E' %properties.input_hyperraman_frequencies[j])) + '.svg'
 
-                avg_wavenumbers, avg_intensities = \
-                    visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                       all_frequencies.harmonic, \
-                                       [all_hR_hv_intensities.harmonic[j]], x_label, \
-                                       [tmp_y_label], [], tmp_name, spectral_boundaries, [])
+                visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                                   all_frequencies.harmonic, [all_hR_hv_intensities.harmonic[j]], \
+                                   x_label, [tmp_y_label], [], tmp_name, spectral_boundaries, [], ticker_distance)
 
         if ('Plot Hyper-Raman VV and HV separately' == plot_commands[i]):
             legends = []
             for j in range(num_hyperraman_configs):
-                tmp_legend = 'Hyper-Raman freq: ' + \
+                tmp_legend = 'Input freq: ' + \
                     str(('%4.1E' %properties.input_hyperraman_frequencies[j]))
                 legends.append(tmp_legend)
 
-            avg_wavenumbers, avg_intensities = \
-                visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                   all_frequencies.harmonic, all_hR_vv_intensities.harmonic, \
-                                   x_label, ['VV polarized hyperraman', ''], legends, \
-                                   'vv_hyperraman.svg', spectral_boundaries, [])
+            visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                               all_frequencies.harmonic, all_hR_vv_intensities.harmonic, \
+                               x_label, [vv_hR_y_label, ''], legends, \
+                               'vv_hyperraman.svg', spectral_boundaries, [], ticker_distance)
 
-            avg_wavenumbers, avg_intensities = \
-                visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                   all_frequencies.harmonic, all_hR_hv_intensities.harmonic, \
-                                   x_label, ['HV polarized hyperraman', ''], legends, \
-                                   'hv_hyperraman.svg', spectral_boundaries, [])
+            visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                               all_frequencies.harmonic, all_hR_hv_intensities.harmonic, \
+                               x_label, [hv_hR_y_label, ''], legends, \
+                               'hv_hyperraman.svg', spectral_boundaries, [], ticker_distance)
 
         if ('Plot all Hyper-Raman together' == plot_commands[i]):
             legends = []
             all_hyperraman_intensities = []
             for j in range(num_hyperraman_configs):
-                tmp_legend = 'VV Hyper-Raman freq: ' + \
+                tmp_legend = 'VV Input freq: ' + \
                     str(('%4.1E' %properties.input_hyperraman_frequencies[j]))
                 legends.append(tmp_legend)
-                tmp_legend = 'HV Hyper-Raman freq: ' + \
+                tmp_legend = 'HV Input freq: ' + \
                     str(('%4.1E' %properties.input_hyperraman_frequencies[j]))
                 legends.append(tmp_legend)
 
                 all_hyperraman_intensities.append(all_hR_vv_intensities.harmonic[j])
                 all_hyperraman_intensities.append(all_hR_hv_intensities.harmonic[j])
 
-            avg_wavenumbers, avg_intensities = \
-                visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
-                                   all_frequencies.harmonic, all_hyperraman_intensities, \
-                                   x_label, 'Hyper-Raman', legends, 'all_hyperraman.svg', \
-                                   spectral_boundaries, ['all one type'])
+            visualize_spectrum(cauchy_type_or_value, cauchy_prefactor, \
+                               all_frequencies.harmonic, all_hyperraman_intensities, x_label, \
+                               hR_y_label, legends, 'all_hyperraman.svg', spectral_boundaries, \
+                               ['all one type'], ticker_distance)
 
     # Part for wrapping up and returning the average wavenumbers and intensities.  Intensities are
     # returned in order IR, Raman, Hyper-Raman VV, Hyper-Raman HV.
