@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -103,7 +103,7 @@ def get_X(harmonic_energies, cubic_forcefield, quartic_forcefield, rotational_co
             if (not is_fermi_resonance(2*vi - vk, kiik, True) or not do_resonance_checks):
                 tmp3 = 1/(2.0*vi - vk)
             else:
-                fermi_resonance = add_fermi_resonance(fermi_resonance, [i, i, k, True])
+                fermi_resonance = add_fermi_resonance(fermi_resonance, [k, i, i, True])
                 tmp3 = 0.0
 
             rhs = rhs + (kiik**2/32.0)*(tmp1 + tmp2 - tmp3)
@@ -133,13 +133,13 @@ def get_X(harmonic_energies, cubic_forcefield, quartic_forcefield, rotational_co
                 if (not is_fermi_resonance(vi - vj + vk, kijk, k == i) or not do_resonance_checks):
                     tmp3 = 1/(vi -vj + vk)
                 else:
-                    fermi_resonance = add_fermi_resonance(fermi_resonance, [i, j, k, k == i])
+                    fermi_resonance = add_fermi_resonance(fermi_resonance, [j, k, i, k == i])
                     tmp3 = 0.0
 
                 if (not is_fermi_resonance(vi + vj - vk, kijk, False) or not do_resonance_checks):
                     tmp4 = 1/(vi + vj - vk)
                 else:
-                    fermi_resonance = add_fermi_resonance(fermi_resonance, [i, j, k, False])
+                    fermi_resonance = add_fermi_resonance(fermi_resonance, [k, i, j, False])
                     tmp4 = 0.0
 
                 B = B + kijk**2/8.0*(tmp1 + tmp2 + tmp3 - tmp4)
@@ -157,6 +157,8 @@ def get_X(harmonic_energies, cubic_forcefield, quartic_forcefield, rotational_co
 
             X[j][i] = np.copy(X[i][j])
 
+    fermi_resonance = sorted(fermi_resonance)
+
     return X, fermi_resonance
 
 
@@ -207,8 +209,6 @@ def anharm_corrected_vibrational_energies(harmonic_energies, cubic_forcefield, q
             j = fermi_resonance[a][1]
             k = fermi_resonance[a][2]
 
-            i, j, k = sorted([i, j, k])
-
             print(i, j, k, harmonic_energies[i], harmonic_energies[j], harmonic_energies[k], \
                   'type: ', fermi_resonance[a][3], \
                   np.multiply(cubic_forcefield[i][j][k], 0.01/(plancs_constant*speed_of_light)))
@@ -279,8 +279,6 @@ def adjust_for_fermi_resonance(fundamental, overtones, combotones, cubic_forcefi
         k = fermi_resonance[a][2]
         fermi_type = fermi_resonance[a][3]
 
-        i, j, k = sorted([i, j, k])
-
         if fermi_type:
             V[i][num_modes + j] = cubic_forcefield[j][k][i]/4.0
             V[num_modes + j][i] = V[i][num_modes + j]
