@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -95,7 +95,8 @@ def cauchy_lincomb(x, y, gamma, x_fit):
 
         for i in range(len(x_fit)):
             for k in range(num_peaks):
-                y_fit[i] = y_fit[i] + y[k]*gamma_constant/(pi*((x_fit[i] - x[k])**2 + \
+                if (y[k] != 0.0):
+                    y_fit[i] = y_fit[i] + y[k]*gamma_constant/(pi*((x_fit[i] - x[k])**2 + \
                                                            gamma_constant**2))
     else:
 
@@ -105,51 +106,9 @@ def cauchy_lincomb(x, y, gamma, x_fit):
                     y_fit[i] = y_fit[i] + y[k]*gamma[k]/(pi*((x_fit[i] - x[k])**2 + \
                                                               gamma[k]**2))
 
-
     return y_fit
 
 
-def get_weighted_averages(x, y):
-
-    avg_y = sum(y)/len(y)
-
-    avg_x = 0
-    for i in range(len(x)):
-        avg_x = avg_x + x[i]*y[i]
-
-    avg_x = avg_x/(avg_y*len(x))
-
-    return avg_x, avg_y
-
-
-# Requires x and y have the same shape
-# Makes averages over all values of a specific column
-def get_set_of_weighted_averages(x, y):
-
-    row_x = len(x)
-    col_x = len(x[0])
-
-    avg_x = np.zeros(col_x)
-    avg_y = np.zeros(col_x)
-
-    if (col_x == 1):
-        for i in range(row_x):
-            avg_x[i] = copy.deepcopy(x[0][i])
-            avg_y[i] = copy.deepcopy(y[0][i])
-
-    else:
-        for i in range(col_x):
-            temp_x = []
-            temp_y = []
-
-            for j in range(row_x):
-                temp_x.append(x[j][i])
-                temp_y.append(y[j][i])
-
-            avg_x[i], avg_y[i] = get_weighted_averages(temp_x, temp_y)
-
-    return avg_x, avg_y
-
 def get_simple_averages(x):
 
     row_x = len(x)
