@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -150,9 +150,10 @@ def get_spectroscopy_indices(redundant_properties, operator):
     return spectroscopy_indices
 
 
-def reduced_dims(mat_dims, remove_elms, rank_el):
+def reduced_dims(mat_dims, num_coordinates, min_element, max_element, rank_el):
 
     end_dims = []
+    remove_elms = num_coordinates - (max_element - min_element + 1)
     for i in range(len(mat_dims) - rank_el):
         end_dims.append(mat_dims[i] - remove_elms)
 
@@ -164,40 +165,43 @@ def reduced_dims(mat_dims, remove_elms, rank_el):
     return end_dims
 
 
-def getting_the_subblocks(larger_mat, remove_elms, out_mat, offset, rank_el):
+def getting_the_subblocks(larger_mat, num_coordinates, min_element, max_element, out_mat, offset, \
+                          rank_el):
 
     dims = np.shape(larger_mat)
     if (len(dims) - rank_el == 1):
-        smaller_mat = larger_mat[0:(list(dims))[0] - remove_elms]
+        smaller_mat = larger_mat[min_element:max_element + 1]
         smaller_mat = np.reshape(smaller_mat, list_product_int(np.shape(smaller_mat)))
         out_mat[offset:offset + len(smaller_mat)] = smaller_mat
         offset = offset + len(smaller_mat)
 
     else:
-        for i in range(list(dims)[0] - remove_elms):
-            offset = getting_the_subblocks(larger_mat[i], remove_elms, out_mat, offset, rank_el)
+        for i in range(min_element, max_element + 1):
+            offset = getting_the_subblocks(larger_mat[i], num_coordinates, min_element, \
+                                           max_element, out_mat, offset, rank_el)
+
     return offset
 
 
-def get_energy_derivatives(index, tensors, redundant_properties, rank_geo, rank_el, num_coordinates, \
-                           vib_degrees_of_freedom, transformation_matrix):
+def get_energy_derivatives(index, tensors, redundant_properties, rank_geo, rank_el, \
+                           num_coordinates, min_element, max_element, transformation_matrix):
 
     energy_derivatives = []
 
     for i in range(len(index)):
         temp = transform_cartesian_to_normal(tensors[index[i]], \
                                              redundant_properties[index[i]].components, rank_geo, \
-                                             num_coordinates, vib_degrees_of_freedom, \
+                                             num_coordinates, min_element, max_element, \
                                              transformation_matrix)
 
-        end_dims = reduced_dims(np.shape(temp), num_coordinates - vib_degrees_of_freedom, rank_el)
+        end_dims = reduced_dims(np.shape(temp), num_coordinates, min_element, max_element, rank_el)
         if (np.shape(temp) != end_dims):
 
             offset = 0
             vib_temp = np.zeros(list_product_int(end_dims))
 
-            getting_the_subblocks(temp, num_coordinates - vib_degrees_of_freedom, vib_temp, offset, \
-                                  rank_el)
+            getting_the_subblocks(temp, num_coordinates, min_element, max_element, vib_temp, \
+                                  offset, rank_el)
 
             vib_temp = np.reshape(vib_temp, end_dims)
             energy_derivatives.append(vib_temp)
@@ -210,7 +214,7 @@ def get_energy_derivatives(index, tensors, redundant_properties, rank_geo, rank_
 
 def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spectroscopy_types, \
                                                 specifications, print_level, temperature, outproj, \
-                                                anharmonic_type):
+                                                anharmonic_type, harmonic_frequency_limits):
 
     # For IR and Raman we need GG, GF, GFF
 
@@ -258,8 +262,10 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
         polariz_grad_index = get_spectroscopy_indices(redundant_properties, polariz_grad_operator)
 
         if (anharmonic):
-            polariz_hess_index = get_spectroscopy_indices(redundant_properties, polariz_hess_operator)
-            polariz_cubic_index = get_spectroscopy_indices(redundant_properties, polariz_cubic_operator)
+            polariz_hess_index = \
+                get_spectroscopy_indices(redundant_properties, polariz_hess_operator)
+            polariz_cubic_index = \
+                get_spectroscopy_indices(redundant_properties, polariz_cubic_operator)
 
     if (hyper_raman == True):
         hyper_polariz_grad_index = get_spectroscopy_indices(redundant_properties, \
@@ -279,26 +285,59 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
 
     hess = tensors[hess_index[0]]
 
+    # Transform harmonic_frequency_limits to a.u. units
+    if (harmonic_frequency_limits != 'Keep all'):
+        if ('Vib modes: 1/m' in specifications):
+            au_harmonic_frequency_limits = \
+                np.multiply(harmonic_frequency_limits, plancs_constant*speed_of_light/hartree_to_joule)
+        elif ('Vib modes: 1/cm' in specifications):
+            au_harmonic_frequency_limits = \
+                np.multiply(harmonic_frequency_limits, plancs_constant*speed_of_light* \
+                            100.0/hartree_to_joule)
+        elif ('Vib modes: 1/s' in specifications):
+            au_harmonic_frequency_limits = \
+                np.multiply(harmonic_frequency_limits, plancs_constant/hartree_to_joule)
+        elif ('Vib modes: ang. 1/s' in specifications):
+            au_harmonic_frequency_limits = \
+                np.multiply(harmonic_frequency_limits, plancs_constant/(2*pi*hartree_to_joule))
+        elif ('Vib modes: Eh' in specifications):
+            au_harmonic_frequency_limits = harmonic_frequency_limits
+        else:
+            print('\n')
+            print('Error in get_vibrational_frequencies_and_intensities')
+            print('You forgot to specify the units for vibrational modes in specifications')
+            exit()
+    else:
+        au_harmonic_frequency_limits = harmonic_frequency_limits
+
     # Do the vibrational analysis
     coords, charges, masses = read_mol(molecule_file)
     # num_coordinates = 3N = total degrees of freedom
-    au_harmonic_vibrational_energies, transformation_matrix, num_coordinates = \
-        get_vib_harm_freqs_and_eigvecs(coords, charges, masses, hess, outproj, print_level)
+    au_harmonic_vibrational_energies, transformation_matrix, num_coordinates, min_element, \
+    max_element = \
+        get_vib_harm_freqs_and_eigvecs(coords, charges, masses, hess, outproj, print_level, \
+                                       au_harmonic_frequency_limits)
+
+    if (min_element != 0):
+        print('WARNING')
+        print('You have chosen to cut off high-frequency modes.  If you do this in combination with')
+        print('anharmonic calculations, be aware that this might severely change your results.')
 
     num_modes = len(au_harmonic_vibrational_energies)
 
+
     if (print_level > 0):
         print('\n')
         print('The harmonic frequencies have been calcuated from the molecular hessian')
 
     if (anharmonic):
         cubic_forcefield = get_energy_derivatives(cubic_index, tensors, redundant_properties, 3, \
-                                                  0, num_coordinates, num_modes, \
+                                                  0, num_coordinates, min_element, max_element, \
                                                   transformation_matrix)
 
-        quartic_forcefield = get_energy_derivatives(quartic_index, tensors, redundant_properties, 4, \
-                                                    0, num_coordinates, num_modes, \
-                                                    transformation_matrix)
+        quartic_forcefield = get_energy_derivatives(quartic_index, tensors, redundant_properties, \
+                                                    4, 0, num_coordinates, min_element, \
+                                                    max_element, transformation_matrix)
 
         # Update to include possible coriolis
         rotational_constant = 0
@@ -309,7 +348,8 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
                              (plancs_constant*speed_of_light)
         SI_cubic_forcefield = np.multiply(cubic_forcefield[0], \
                                           hartree_to_joule/(bohr_to_meter**3*electron_mass**1.5))
-        red_cubic_forcefield = transform_to_reduced_nm_prep(SI_cubic_forcefield, harmonic_recp_m_wn, 0)
+        red_cubic_forcefield = \
+            transform_to_reduced_nm_prep(SI_cubic_forcefield, harmonic_recp_m_wn, 0)
 
         SI_quartic_forcefield = np.multiply(quartic_forcefield[0], \
                                             hartree_to_joule/(bohr_to_meter**4*electron_mass**2))
@@ -354,7 +394,8 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
                                                SI_anharmonic_energies.fundamental, \
                                                SI_anharmonic_energies.overtones, \
                                                SI_anharmonic_energies.combotones, \
-                                               conversion_factor=(0.01/(plancs_constant*speed_of_light)))
+                                               conversion_factor=(0.01/ \
+                                                   (plancs_constant*speed_of_light)))
 
     # 1/s not Angular
     vibrational_frequencies = anharmonicProperty(SI_harmonic_vibrational_energies, \
@@ -431,7 +472,7 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
     # Use the info from the vib analysis to transfor all tensors to normal coordinates
     if (IR == True):
         dipole_gradient = get_energy_derivatives(dip_grad_index, tensors, redundant_properties, \
-                                                 1, 1, num_coordinates, num_modes, \
+                                                 1, 1, num_coordinates, min_element, max_element, \
                                                  transformation_matrix)
 
         if (len(dipole_gradient) > 1):
@@ -450,15 +491,16 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
         SI_dipole_gradient = np.multiply(dipole_gradient, hartree_to_coulomb/sqrt(electron_mass))
 
         # Harmonic transition moment
-        harmonic_transition_dipole_moment = get_harmonic_transition_moment(SI_dipole_gradient[0], qi2)
+        harmonic_transition_dipole_moment = \
+            get_harmonic_transition_moment(SI_dipole_gradient[0], qi2)
         if (anharmonic):
 
             red_dipole_gradient = transform_to_reduced_nm_prep(SI_dipole_gradient[0], \
                                                                recp_m_wavenumbers.harmonic, 1)
 
             dipole_hessian = get_energy_derivatives(dip_hess_index, tensors, redundant_properties, \
-                                                    2, 1, num_coordinates, num_modes, \
-                                                    transformation_matrix)
+                                                    2, 1, num_coordinates, min_element, \
+                                                    max_element, transformation_matrix)
 
             dipole_hessian = np.multiply(dipole_hessian[0], hartree_to_coulomb/ \
                                          (bohr_to_meter*electron_mass))
@@ -466,7 +508,7 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
                                                               recp_m_wavenumbers.harmonic, 1)
 
             dipole_cubic = get_energy_derivatives(dip_cubic_index, tensors, redundant_properties, \
-                                                  3, 1, num_coordinates, num_modes, \
+                                                  3, 1, num_coordinates, min_element, max_element, \
                                                   transformation_matrix)
 
             dipole_cubic = np.multiply(dipole_cubic, hartree_to_coulomb/ \
@@ -480,13 +522,15 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
                                                        red_dipole_cubic, red_cubic_forcefield, \
                                                        red_quartic_forcefield, \
                                                        harmonic_transition_dipole_moment, \
-                                                       SI_anharmonic_energies.harmonic, 'No coriolis', \
-                                                       0, anharmonic_type)
+                                                       SI_anharmonic_energies.harmonic, \
+                                                       'No coriolis', 0, anharmonic_type)
 
         else:
-            fundamental_transition_dipole_moment = np.zeros(np.shape(harmonic_transition_dipole_moment))
+            fundamental_transition_dipole_moment = \
+                np.zeros(np.shape(harmonic_transition_dipole_moment))
             overtone_transition_dipole_moment = np.zeros(np.shape(harmonic_transition_dipole_moment))
-            combotone_transition_dipole_moment = np.zeros(np.shape(harmonic_transition_dipole_moment))
+            combotone_transition_dipole_moment = \
+                np.zeros(np.shape(harmonic_transition_dipole_moment))
 
             transition_dipole_moment = anharmonicProperty(harmonic_transition_dipole_moment, \
                                                           fundamental_transition_dipole_moment, \
@@ -539,8 +583,8 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
 
         au_polarizability_gradients = get_energy_derivatives(polariz_grad_index, tensors, \
                                                              redundant_properties, 1, 2, \
-                                                             num_coordinates, num_modes, \
-                                                             transformation_matrix)
+                                                             num_coordinates, min_element, \
+                                                             max_element, transformation_matrix)
 
         SI_polarizability_gradients = np.multiply(au_polarizability_gradients, \
                                        (hartree_to_coulomb**2*bohr_to_meter)/ \
@@ -549,16 +593,16 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
         if (anharmonic):
             polarizability_hessian = get_energy_derivatives(polariz_hess_index, tensors, \
                                                             redundant_properties, 2, 2, \
-                                                            num_coordinates, num_modes, \
-                                                            transformation_matrix)
+                                                            num_coordinates, min_element, \
+                                                            max_element, transformation_matrix)
 
             polarizability_hessian = np.multiply(polarizability_hessian, hartree_to_coulomb**2/ \
                                                  (hartree_to_joule*electron_mass))
 
             polarizability_cubic = get_energy_derivatives(polariz_cubic_index, tensors, \
                                                           redundant_properties, 3, 2, \
-                                                          num_coordinates, num_modes, \
-                                                          transformation_matrix)
+                                                          num_coordinates, min_element, \
+                                                          max_element, transformation_matrix)
 
             polarizability_cubic = np.multiply(polarizability_cubic, hartree_to_coulomb**2/ \
                                                (hartree_to_joule*bohr_to_meter*electron_mass**1.5))
@@ -619,10 +663,11 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
 
                     transition_polarizability_moment = \
                         get_anharm_corrected_transition_moment(red_polariz_gradient, \
-                                                               red_polariz_hessian, red_polariz_cubic, \
+                                                               red_polariz_hessian, \
+                                                               red_polariz_cubic, \
                                                                red_cubic_forcefield, \
                                                                red_quartic_forcefield, \
-                                                            harmonic_transition_polarizability_moment, \
+                                                        harmonic_transition_polarizability_moment, \
                                                                SI_anharmonic_energies.harmonic, \
                                                                'No coriolis', 0, anharmonic_type)
 
@@ -664,7 +709,8 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
                   input_raman_modes]))
             for i in range(len(recp_m_wavenumbers.harmonic)):
                 print('%2d %16.6f' %(i, recp_m_wavenumbers.harmonic[i]), '\t'.join([format_string % \
-                      raman_intensities.harmonic[j][i] for j in range(len(raman_intensities.harmonic))]))
+                      raman_intensities.harmonic[j][i] for j in \
+                          range(len(raman_intensities.harmonic))]))
 
     else:
         raman_intensities = anharmonicProperty(['You did not ask for Raman intensities'], \
@@ -677,7 +723,8 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
 
         au_hyper_polarizability_gradients = \
             get_energy_derivatives(hyper_polariz_grad_index, tensors, redundant_properties, 1, \
-                                   3, num_coordinates, num_modes, transformation_matrix)
+                                   3, num_coordinates, min_element, max_element, \
+                                   transformation_matrix)
 
         SI_hyper_polarizability_gradients = \
             np.multiply(au_hyper_polarizability_gradients, hartree_to_coulomb**3*bohr_to_meter**2/ \
@@ -686,14 +733,14 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
         if (anharmonic):
             beta_hessian = get_energy_derivatives(hyper_polariz_hess_index, tensors, \
                                                   redundant_properties, 2, 3, num_coordinates, \
-                                                  num_modes, transformation_matrix)
+                                                  min_element, max_element, transformation_matrix)
 
             beta_hessian = np.multiply(beta_hessian, hartree_to_coulomb**3*bohr_to_meter/ \
                                        (hartree_to_joule**2*electron_mass))
 
             beta_cubic = get_energy_derivatives(hyper_polariz_cubic_index, tensors, \
                                                 redundant_properties, 3, 3, num_coordinates, \
-                                                num_modes, transformation_matrix)
+                                                min_element, max_element, transformation_matrix)
 
             beta_cubic = np.multiply(beta_cubic, hartree_to_coulomb**3/ \
                                      (hartree_to_joule**2*electron_mass**1.5))
@@ -741,7 +788,8 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
 
                     beta_transition_moment = \
                         get_anharm_corrected_transition_moment(red_beta_gradient, red_beta_hessian, \
-                                                               red_beta_cubic, red_cubic_forcefield, \
+                                                               red_beta_cubic, \
+                                                               red_cubic_forcefield, \
                                                                red_quartic_forcefield, \
                                                                harmonic_beta_transition_moment, \
                                                                SI_anharmonic_energies.harmonic, \
@@ -778,15 +826,17 @@ def get_vibrational_frequencies_and_intensities(tensor_file, molecule_file, spec
 
 
     else:
-        hyperraman_vv_intensities = anharmonicProperty(['You did not ask for Hyper-Raman intensities'], \
-                                                       ['You did not ask for Hyper-Raman intensities'], \
-                                                       ['You did not ask for Hyper-Raman intensities'], \
-                                                       ['You did not ask for Hyper-Raman intensities'])
+        hyperraman_vv_intensities = \
+            anharmonicProperty(['You did not ask for Hyper-Raman intensities'], \
+                               ['You did not ask for Hyper-Raman intensities'], \
+                               ['You did not ask for Hyper-Raman intensities'], \
+                               ['You did not ask for Hyper-Raman intensities'])
 
-        hyperraman_hv_intensities = anharmonicProperty(['You did not ask for Hyper-Raman intensities'], \
-                                                       ['You did not ask for Hyper-Raman intensities'], \
-                                                       ['You did not ask for Hyper-Raman intensities'], \
-                                                       ['You did not ask for Hyper-Raman intensities'])
+        hyperraman_hv_intensities = \
+            anharmonicProperty(['You did not ask for Hyper-Raman intensities'], \
+                               ['You did not ask for Hyper-Raman intensities'], \
+                               ['You did not ask for Hyper-Raman intensities'], \
+                               ['You did not ask for Hyper-Raman intensities'])
         input_hyperraman_modes = ['You did not ask for Hyper-Raman intensities']
 
     properties = vibrationalProperty(vibrational_modes, ir_intensities, input_raman_modes, \
