@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -123,7 +123,7 @@ def get_hyperraman_SI_scs(incident_wn, wavenumbers, beta2, T):
     exp_denom = get_exp_denominator(wavenumbers, T)
 
     for i in range(num_modes):
-        if (wavenumbers[i] == 0.0):
+        if (wavenumbers[i] == 0.0 or wavenumbers[i].imag != 0):
             sigma[i] = 0.0
             exp_denom[i] = 1.0
         else:
