@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -100,8 +100,9 @@ def get_rscattering_cross_section(exp_denominator, incident_wavenumbers, wavenum
     intensities = np.zeros((num_modes))
 
     for i in range(num_modes):
-        intensities[i] = exp_denominator[i]*(incident_wavenumbers - \
-                         wavenumbers[i])**4*combined_polarizabilities[i]
+        intensities[i] = (incident_wavenumbers - wavenumbers[i])**4*combined_polarizabilities[i]
+
+    intensities = np.divide(intensities, exp_denominator)
 
     return intensities
 
@@ -195,6 +196,10 @@ def raman_scattering_cross_section(polarizability_transition_moment, incident_wa
                                           wavenumbers.combotones[i], \
                                           combined_polarizabilities.combotones[i])
 
+    # This is only done for practical reasons.
+    for i in range(num_modes):
+        intensities.combotones[i][i] = 0.0
+
     if (print_level > 3):
         print('\n')
         print('Raman SI values for input wavenumer ', incident_wavenumbers)
@@ -394,7 +399,7 @@ def get_raman_intensities(specifications, incident_wavenumbers, polarizability_t
 
     if (print_level > 2):
         print('\n')
-        print('SCS: Absolute differential scattering cross section SI arbitrary units, input energy. ', \
+        print('SCS: Absolute differential scattering cross section SI units, input energy. ', \
                 au_incident_vibration_energy)
         print('%4s %14s %28s' %('Mode', '45+4', '45+7'))
         for j in range(num_modes):
