@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -9,8 +9,7 @@
 # The package is released under a LGPL licence.
 # For questions, please contact on karen.o.dundas@uit.no
 
-from .test_cauchy import test_get_simple_averages, test_get_set_of_weighted_averages, \
-                         test_get_weighted_averages, test_get_interquartile_range, test_get_gamma, \
+from .test_cauchy import test_get_simple_averages, test_get_interquartile_range, test_get_gamma, \
                          test_cauchy_lincomb, test_get_standard_deviation
 from .test_get_spectroscopy import test_get_vibrational_frequencies_and_intensities, \
                                    test_which_spectroscopies_to_be_calculated, \
@@ -23,8 +22,10 @@ from .test_transform_nc_to_nm import test_list_product_int, \
                                      test_transform_cartesian_to_normal_one_rank, \
                                      test_transform_cartesian_to_normal
 from .test_vib_analysis import test_mol_is_linear, test_read_mol, test_project_out_transl_and_rot, \
-                               test_get_vib_harm_freqs_and_eigvecs, test_get_vibrational_w
-from .test_ir import test_square_then_sum, test_qi_prefactor2, test_get_ir_intensities, test_get_harmonic_transition_moment
+                               test_get_vib_harm_freqs_and_eigvecs, test_get_vibrational_w_and_T, \
+                               test_cut_at_harmonic_frequency_limits
+from .test_ir import test_square_then_sum, test_qi_prefactor2, test_get_ir_intensities, \
+                     test_get_harmonic_transition_moment
 from .test_raman import test_get_combined_polarizabilites, test_raman_scattering_cross_section, \
                         test_get_exp_denominator, test_get_b2_term, test_get_a2_term, \
                         test_requested_unit_incident_mode, test_get_rscattering_cross_section
@@ -35,4 +36,5 @@ from .test_anharmonic import test_get_X, test_get_anharm_fundamental_transition_
                              test_transform_to_reduced_nm, test_transform_to_reduced_nm_prep, \
                              test_get_overtone_transition_moment, \
                              test_get_anharm_corrected_transition_moment
-from .test_resonance_checks import test_is_fermi_resonance, test_is_11_resonance, test_add_fermi_resonance
+from .test_resonance_checks import test_is_fermi_resonance, test_is_11_resonance, \
+                                   test_add_fermi_resonance
