@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -9,9 +9,8 @@
 # The package is released under a LGPL licence.
 # For questions, please contact on karen.o.dundas@uit.no
 
-from spectroscpy import get_interquartile_range, get_gamma, cauchy_lincomb, get_weighted_averages, \
-                        get_set_of_weighted_averages, get_simple_averages, average_over_snapshots, \
-                        get_standard_deviation
+from spectroscpy import get_interquartile_range, get_gamma, cauchy_lincomb, get_simple_averages, \
+                        average_over_snapshots, get_standard_deviation
 import numpy as np
 
 def test_get_standard_deviation():
@@ -62,46 +61,6 @@ def test_get_simple_averages():
     assert np.allclose(ref_avg_y, avg_y)
 
 
-def test_get_set_of_weighted_averages():
-
-    ref_avg_x = [1.12019608,  4.12923077,  6.23090909,  2.275,      10.01783784]
-    ref_avg_y = [10.2,  2.6,  4.4,  2.0,   7.4]
-
-    x = [[1.15, 4, 6.1, 2.3, 9.8], [1.13, 4.15, 6.5, 2.4, 10], [1, 4.13, 6.11, 2.25, 10.1], \
-         [1.1, 4.25, 6.2, 2.18, 10.05], [1.2, 4.16, 6.21, 2.32, 10.12]]
-    y = [[10, 3, 4, 2, 7], [11, 4, 5, 1, 8], [9, 2, 5, 1, 8], [10, 2, 5, 3, 6], [11, 2, 3, 3, 8]]
-
-    avg_x, avg_y = get_set_of_weighted_averages(x, y)
-
-    assert np.allclose(ref_avg_x, avg_x)
-    assert np.allclose(ref_avg_y, avg_y)
-
-    ref_avg_x = [1.15, 4, 6.1, 2.3, 9.8]
-    ref_avg_y = [10, 3, 4, 2, 7]
-
-    x = [[1.15, 4, 6.1, 2.3, 9.8]]
-    y = [[10, 3, 4, 2, 7]]
-
-    avg_x, avg_y = get_set_of_weighted_averages(x, y)
-
-    assert np.allclose(ref_avg_x, avg_x)
-    assert np.allclose(ref_avg_y, avg_y)
-
-
-def test_get_weighted_averages():
-
-    ref_avg_y = 10.2
-    ref_avg_x = 1.1201960784313725
-
-    x = [1.15, 1.13, 1, 1.1, 1.2]
-    y = [10, 11, 9, 10, 11]
-
-    avg_x, avg_y = get_weighted_averages(x, y)
-
-    assert ref_avg_x == avg_x
-    assert ref_avg_y == avg_y
-
-
 def test_get_interquartile_range():
 
     x = [1.15, 1.13, 1, 1.1, 1.2]
