@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -182,8 +182,8 @@ def test_get_rscattering_cross_section():
     au_combined_polarizabilites = [0.14867859, 0.61365425, 0.08134748, \
                                    0.01808905, 0.11121733, 0.05762326]
 
-    ref_intensities = [1.49220758e+24, 6.16921576e+24, 1.34505975e+24,
-                       3.10585929e+23, 1.94762215e+24, 7.58566102e+23]
+    ref_intensities = [1.49220758e+24, 6.16921579e+24, 1.34555457e+24,
+                       3.10875251e+23, 1.95059450e+24, 2.20386779e+24]
 
     intensities = get_rscattering_cross_section(exp_denominator, SI_incident_wavenumbers, \
                                                 SI_wavenumbers.harmonic, au_combined_polarizabilites)
@@ -289,13 +289,13 @@ def test_get_raman_intensities():
     specifications = ['Raman: SCS 45+4, SI units']
     SI_incident_wavenumbers = 2194746.0394200613
 
-    ref_harmonic_intensities = [1.97324527e-67, 1.24638727e-56, 3.80182355e-65, 4.08892111e-66]
-    ref_fundamental_intensities = [6.02506388e-68, 1.27556523e-56, 1.92631742e-65, 5.49409245e-66]
-    ref_overtones_intensities = [8.41271531e-60, 2.06854081e-60, 2.50960194e-57, 2.51092286e-57]
-    ref_combotones_intensities = [[0.00000000e+00, 1.62008604e-71, 1.06632137e-58, 1.06663713e-58],
-                                  [1.62008604e-71, 0.00000000e+00, 1.70091177e-67, 7.78409218e-67],
-                                  [1.06632137e-58, 1.70091177e-67, 0.00000000e+00, 1.48454378e-57],
-                                  [1.06663713e-58, 7.78409218e-67, 1.48454378e-57, 0.00000000e+00]]
+    ref_harmonic_intensities = [1.97324659e-67, 1.24708655e-56, 1.32864198e-64, 1.42941164e-65]
+    ref_fundamental_intensities = [6.02507054e-68, 1.27625433e-56, 3.73260784e-65, 1.06455281e-65]
+    ref_overtones_intensities = [8.41271531e-60, 2.06854112e-60, 2.78209485e-57, 2.78346258e-57]
+    ref_combotones_intensities = [[0.00000000e+00, 1.62008604e-71, 1.06632183e-58, 1.06663759e-58],
+                                  [1.62008604e-71, 0.00000000e+00, 1.70114589e-67, 7.78516352e-67],
+                                  [1.06632183e-58, 1.70114589e-67, 0.00000000e+00, 1.67250206e-57],
+                                  [1.06663759e-58, 7.78516352e-67, 1.67250206e-57, 0.00000000e+00]]
 
     intensities = get_raman_intensities(specifications, SI_incident_wavenumbers, \
                                         transition_polarizability_moment, \
@@ -311,13 +311,13 @@ def test_get_raman_intensities():
                        np.multiply(intensities.combotones, 1.0e57))
 
     specifications = ['Raman: SCS 45+7, SI units']
-    ref_harmonic_intensities = [3.41894971e-67, 1.51006409e-56, 6.65319122e-65, 6.63629892e-66]
-    ref_fundamental_intensities = [9.35423812e-68, 1.51091847e-56, 3.37105549e-65, 7.86578614e-66]
-    ref_overtones_intensities = [1.14574702e-59, 2.59310155e-60, 3.85108814e-57, 3.85311669e-57]
-    ref_combotones_intensities = [[0.00000000e+00, 2.11140052e-71, 1.86606239e-58, 1.86661497e-58],
-                                  [2.11140052e-71, 0.00000000e+00, 2.97659560e-67, 8.82110291e-67],
-                                  [1.86606239e-58, 2.97659560e-67, 0.00000000e+00, 2.59795161e-57],
-                                  [1.86661497e-58, 8.82110291e-67, 2.59795161e-57, 0.00000000e+00]]
+    ref_harmonic_intensities = [3.41895200e-67, 1.51091130e-56, 2.32512347e-64, 2.31992809e-65]
+    ref_fundamental_intensities = [9.35424846e-68, 1.51173472e-56, 6.53206372e-65, 1.52409971e-65]
+    ref_overtones_intensities = [1.14574702e-59, 2.59310194e-60, 4.26923981e-57, 4.27134034e-57]
+    ref_combotones_intensities = [[0.00000000e+00, 2.11140052e-71, 1.86606320e-58, 1.86661577e-58],
+                                  [2.11140052e-71, 0.00000000e+00, 2.97700530e-67, 8.82231697e-67],
+                                  [1.86606320e-58, 2.97700530e-67, 0.00000000e+00, 2.92687860e-57],
+                                  [1.86661577e-58, 8.82231697e-67, 2.92687860e-57, 0.00000000e+00]]
 
     intensities = get_raman_intensities(specifications, SI_incident_wavenumbers, \
                                         transition_polarizability_moment, \
@@ -331,7 +331,7 @@ def test_get_raman_intensities():
                        np.multiply(intensities.overtones, 1.0e57))
     assert np.allclose(np.multiply(ref_combotones_intensities, 1.0e57), \
                        np.multiply(intensities.combotones, 1.0e57))
-    
+
     # Temperature 400K
     specifications = ['Raman: CPG 45+4, a.u.']
     ref_harmonic_intensities = [1.61462441e-12, 4.20770947e-02, 1.67601953e-11, 1.80243517e-12]
@@ -341,21 +341,15 @@ def test_get_raman_intensities():
                                   [2.84466723e-16, 0.00000000e+00, 7.12783900e-13, 3.26202703e-12],
                                   [9.16030432e-04, 7.12783900e-13, 0.00000000e+00, 1.49842181e-03],
                                   [9.16296799e-04, 3.26202703e-12, 1.49842181e-03, 0.00000000e+00]]
-    
+
     intensities = get_raman_intensities(specifications, SI_incident_wavenumbers, \
                                         transition_polarizability_moment, \
                                         CO2_wavenumbers, True, 0, 400)
 
-    print(intensities.harmonic)
-    print(intensities.fundamental)
-    print(intensities.overtones)
-    print(intensities.combotones)
     assert np.allclose(ref_harmonic_intensities, intensities.harmonic)
     assert np.allclose(ref_fundamental_intensities, intensities.fundamental)
     assert np.allclose(ref_overtones_intensities, intensities.overtones)
     assert np.allclose(ref_combotones_intensities, intensities.combotones)
-    
-    
 
 
 def test_get_combined_polarizabilites():
@@ -380,22 +374,24 @@ def test_raman_scattering_cross_section():
     raman_type = ['45+7']
 
     CO2_harmonic_wavenumbers = [308803.62879803, 169409.60714536,  15856.18156937,  15852.54619014]
-    CO2_fundamental_wavenumbers = [298437.35928427, 170192.2063791,   26246.64170339,  26247.44867762]
+    CO2_fundamental_wavenumbers = \
+        [298437.35928427, 170192.2063791,   26246.64170339,  26247.44867762]
     CO2_overtones_wavenumbers = [594112.21291436, 339972.06592672,  61950.8418014,   61957.63980011]
-    CO2_combotones_wavenumbers = [[     0.        , 466883.50538247, 317954.17644414, 317953.1650671 ],
-                                 [466883.50538247,      0.        , 198506.6568093 , 198507.79874123],
-                                 [317954.17644414, 198506.6568093 ,      0.        ,  59021.90967648],
-                                 [317953.1650671,  198507.79874123,  59021.90967648,      0.        ]]
+    CO2_combotones_wavenumbers = \
+        [[     0.        , 466883.50538247, 317954.17644414, 317953.1650671 ],
+         [466883.50538247,      0.        , 198506.6568093 , 198507.79874123],
+         [317954.17644414, 198506.6568093 ,      0.        ,  59021.90967648],
+         [317953.1650671,  198507.79874123,  59021.90967648,      0.        ]]
 
     SI_incident_wavenumbers = 2194746.0394200613
 
-    ref_harmonic_intensities = [3.41894971e-67, 1.51006409e-56, 6.65319122e-65, 6.63629892e-66]
-    ref_fundamental_intensities = [9.35423812e-68, 1.51091847e-56, 3.37105549e-65, 7.86578614e-66]
-    ref_overtones_intensities = [1.14574702e-59, 2.59310155e-60, 3.85108814e-57, 3.85311669e-57]
-    ref_combotones_intensities = [[0.00000000e+00, 2.11140052e-71, 1.86606239e-58, 1.86661497e-58],
-                                  [2.11140052e-71, 0.00000000e+00, 2.97659560e-67, 8.82110291e-67],
-                                  [1.86606239e-58, 2.97659560e-67, 0.00000000e+00, 2.59795161e-57],
-                                  [1.86661497e-58, 8.82110291e-67, 2.59795161e-57, 0.00000000e+00]]
+    ref_harmonic_intensities = [3.41895200e-67, 1.51091130e-56, 2.32512347e-64, 2.31992809e-65]
+    ref_fundamental_intensities = [9.35424846e-68, 1.51173472e-56, 6.53206372e-65, 1.52409971e-65]
+    ref_overtones_intensities = [1.14574702e-59, 2.59310194e-60, 4.26923981e-57, 4.27134034e-57]
+    ref_combotones_intensities = [[           0.0, 2.11140052e-71, 1.86606320e-58, 1.86661577e-58],
+                                  [2.11140052e-71,            0.0, 2.97700530e-67, 8.82231697e-67],
+                                  [1.86606320e-58, 2.97700530e-67,            0.0, 2.92687860e-57],
+                                  [1.86661577e-58, 8.82231697e-67, 2.92687860e-57,            0.0]]
 
     intensities = raman_scattering_cross_section(transition_polarizability_moment, \
                                                  SI_incident_wavenumbers, \
@@ -412,13 +408,13 @@ def test_raman_scattering_cross_section():
 
     raman_type = ['45+4']
 
-    ref_harmonic_intensities = [1.97324527e-67, 1.24638727e-56, 3.80182355e-65, 4.08892111e-66]
-    ref_fundamental_intensities = [6.02506388e-68, 1.27556523e-56, 1.92631742e-65, 5.49409245e-66]
-    ref_overtones_intensities = [8.41271531e-60, 2.06854081e-60, 2.50960194e-57, 2.51092286e-57]
-    ref_combotones_intensities = [[0.00000000e+00, 1.62008604e-71, 1.06632137e-58, 1.06663713e-58],
-                                  [1.62008604e-71, 0.00000000e+00, 1.70091177e-67, 7.78409218e-67],
-                                  [1.06632137e-58, 1.70091177e-67, 0.00000000e+00, 1.48454378e-57],
-                                  [1.06663713e-58, 7.78409218e-67, 1.48454378e-57, 0.00000000e+00]]
+    ref_harmonic_intensities = [1.97324659e-67, 1.24708655e-56, 1.32864198e-64, 1.42941164e-65]
+    ref_fundamental_intensities = [6.02507054e-68, 1.27625433e-56, 3.73260784e-65, 1.06455281e-65]
+    ref_overtones_intensities = [8.41271531e-60, 2.06854112e-60, 2.78209485e-57, 2.78346258e-57]
+    ref_combotones_intensities = [[0.00000000e+00, 1.62008604e-71, 1.06632183e-58, 1.06663759e-58],
+                                  [1.62008604e-71, 0.00000000e+00, 1.70114589e-67, 7.78516352e-67],
+                                  [1.06632183e-58, 1.70114589e-67, 0.00000000e+00, 1.67250206e-57],
+                                  [1.06663759e-58, 7.78516352e-67, 1.67250206e-57, 0.00000000e+00]]
 
     intensities = raman_scattering_cross_section(transition_polarizability_moment, \
                                                  SI_incident_wavenumbers, \
@@ -449,8 +445,8 @@ def test_get_exp_denominator():
 
 def test_get_b2_term():
 
-    ref_b2 = [0.021239769179061247, 0.03931133318988317, 0.011532766376159364, 0.0025841499253242495, \
-              0.00832255012728591, 0.008231082946554976]
+    ref_b2 = [0.021239769179061247, 0.03931133318988317, 0.011532766376159364, 
+              0.0025841499253242495, 0.00832255012728591, 0.008231082946554976]
 
     b2 = get_b2_term(au_polarizability_gradient)
 
