@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -15,7 +15,7 @@
 # Thanks also to Per-Olof Åstrand on these routines
 
 from spectroscpy import get_vib_harm_freqs_and_eigvecs, project_out_transl_and_rot, read_mol, \
-                        mol_is_linear, get_vibrational_w
+                        mol_is_linear, get_vibrational_w_and_T, cut_at_harmonic_frequency_limits
 import os
 import numpy as np
 
@@ -78,8 +78,10 @@ def test_read_mol():
     data_dir = '{0}/'.format(os.path.dirname(__file__))
     mol_name = data_dir + 'H2O2.mol'
 
-    ref_coordinates = [[1.69509813, -0.01831334, 1.84778681], [-0.83741626, -1.47927283, -1.84733382], \
-                       [0.12223015, 0.06073168, -1.31223], [-0.11825048, -0.07620551, 1.31178901]]
+    ref_coordinates = [[1.69509813, -0.01831334, 1.84778681], \
+                       [-0.83741626, -1.47927283, -1.84733382], \
+                       [0.12223015, 0.06073168, -1.31223], \
+                       [-0.11825048, -0.07620551, 1.31178901]]
     ref_charges = [1, 1, 8, 8]
     ref_masses = [1.007825, 1.007825, 15.994915, 15.994915]
 
@@ -208,63 +210,88 @@ def test_project_out_transl_and_rot():
 
 def test_get_vib_harm_freqs_and_eigvecs():
 
+    harmonic_frequency_limits = 'Keep all'
+
     ref_T = \
-        [[-1.53222357e-02, -1.53669888e-02,  3.22981009e-03,  4.17339724e-03, \
-          -4.03628914e-04, -8.54362528e-04,  1.13488075e-03, -2.88616863e-04, \
-          -3.77606108e-04, -1.62362393e-03, -1.62362393e-03,  5.14035877e-04], \
-         [-4.88454587e-04, -6.26090972e-04, -2.86856313e-04,  9.19391442e-04, \
-           5.97284932e-04,  1.58823715e-02, -1.14146847e-03,  7.96520914e-03, \
-           3.28688007e-03, -1.64709234e-03, -1.64709234e-03, -9.62826828e-03], \
-         [-4.54192140e-03, -4.36068019e-03, -1.50488540e-02, -1.51582554e-02, \
-          -3.00715934e-03,  3.65915208e-04, -1.96142805e-03, -2.50207663e-04, \
-          -2.48190436e-05,  3.54138948e-03,  3.54138948e-03, -4.62509663e-06], \
-         [-8.12088720e-03,  8.23711286e-03, -1.38024617e-03,  2.89722010e-03, \
-          -3.15677757e-04, -1.33095828e-02, -4.84150203e-03,  6.19763680e-03, \
-          -2.44347259e-03, -1.40658966e-03, -1.40658966e-03, -9.84941656e-03], \
-         [-1.30330770e-02,  1.29622276e-02, -2.92412422e-03,  3.13500922e-03, \
-           6.51580245e-04,  8.70769872e-03, -4.48933861e-03, -6.19650723e-04, \
-           1.74382574e-03,  6.45440786e-04,  6.45440786e-04,  8.99006010e-03], \
-         [-4.54112240e-03,  4.34618794e-03,  1.50507102e-02, -1.51597004e-02, \
-           3.00626300e-03, -3.80756305e-04,  3.45825375e-03, -1.30143133e-03, \
-           2.00114363e-03,  2.48623031e-03,  2.48623031e-03, -2.63082451e-04], \
-         [ 5.11949879e-04, -5.26040879e-04,  1.11679665e-03,  1.44609639e-04, \
-          -1.70604122e-04,  9.86304146e-04, -1.50682473e-03, -2.55382512e-03, \
-           2.03048197e-04, -9.73793860e-04, -9.73793860e-04, -1.59801919e-03], \
-         [ 8.20763107e-04, -8.20829892e-04,  7.77635495e-04, -7.65522406e-04, \
-          -1.48224530e-04, -4.63682059e-04, -5.10657338e-03,  4.11025264e-03, \
-           9.19617398e-04,  1.06259271e-04,  1.06259271e-04,  3.28095483e-03], \
-         [ 2.86187714e-04, -3.45501456e-04, -6.03883287e-04,  9.55520058e-04, \
-           4.06140663e-03, -1.10939371e-04, -7.45728136e-04,  7.80849642e-04, \
-          -3.73049118e-04,  3.26180135e-03,  3.26180135e-03,  1.36954278e-03], \
-         [ 9.65179904e-04,  9.75287860e-04, -1.23333598e-03, -5.90122786e-04, \
-           2.15926979e-04, -9.38468746e-05,  5.54270900e-04, -2.53545305e-04, \
-          -4.05103152e-04, -1.53831645e-03, -1.53831645e-03, -2.06526629e-04], \
-         [ 3.12162589e-05,  4.35411782e-05, -5.75314541e-04,  5.10058319e-04, \
-           6.95346751e-05, -1.08571583e-03,  1.06062494e-03, -1.78354784e-03, \
-           5.61812796e-03, -8.09242269e-04, -8.09242269e-04,  4.20426292e-04], \
-         [ 2.86126589e-04,  3.46414599e-04,  6.03766333e-04,  9.54786678e-04, \
-          -4.06135015e-03,  1.11874495e-04, -2.34995409e-04,  6.84086724e-04, \
-          -1.83586994e-04,  3.16228875e-03,  3.16228875e-03,  1.34778770e-03]]
+        [[-1.53222357e-02, -1.53669888e-02,  3.22981009e-03,
+           4.17339724e-03, -4.03628914e-04, -8.54362528e-04],
+         [-4.88454587e-04, -6.26090972e-04, -2.86856313e-04,
+           9.19391442e-04,  5.97284932e-04,  1.58823715e-02],
+         [-4.54192140e-03, -4.36068019e-03, -1.50488540e-02,
+          -1.51582554e-02, -3.00715934e-03,  3.65915208e-04],
+         [-8.12088720e-03,  8.23711286e-03, -1.38024617e-03,
+           2.89722010e-03, -3.15677757e-04, -1.33095828e-02],
+         [-1.30330770e-02,  1.29622276e-02, -2.92412422e-03,
+           3.13500922e-03,  6.51580245e-04,  8.70769872e-03],
+         [-4.54112240e-03,  4.34618794e-03,  1.50507102e-02,
+          -1.51597004e-02,  3.00626300e-03, -3.80756305e-04],
+         [ 5.11949879e-04, -5.26040879e-04,  1.11679665e-03,
+           1.44609639e-04, -1.70604122e-04,  9.86304146e-04],
+         [ 8.20763107e-04, -8.20829892e-04,  7.77635495e-04,
+          -7.65522406e-04, -1.48224530e-04, -4.63682059e-04],
+         [ 2.86187714e-04, -3.45501456e-04, -6.03883287e-04,
+           9.55520058e-04,  4.06140663e-03, -1.10939371e-04],
+         [ 9.65179904e-04,  9.75287860e-04, -1.23333598e-03,
+          -5.90122786e-04,  2.15926979e-04, -9.38468746e-05],
+         [ 3.12162589e-05,  4.35411782e-05, -5.75314541e-04,
+           5.10058319e-04,  6.95346751e-05, -1.08571583e-03],
+         [ 2.86126589e-04,  3.46414599e-04,  6.03766333e-04,
+           9.54786678e-04, -4.06135015e-03,  1.11874495e-04]]
 
 
     ref_num_coordinates = 12
     ref_vib_energies = [0.01890185358818863, 0.018867981779968866, 0.008117022153354516, \
                         0.007240632902872262, 0.00677517594096139, 0.0008338069322834605]
+    ref_min_element = 0
+    ref_max_element = 5
 
     coordinates = [[1.69509813, -0.01831334, 1.84778681], [-0.83741626, -1.47927283, -1.84733382], \
                    [0.12223015, 0.06073168, -1.31223], [-0.11825048, -0.07620551, 1.31178901]]
     charges = [1, 1, 8, 8]
     masses = [1.007825, 1.007825, 15.994915, 15.994915]
 
-    vib_energies, transformation_matrix, num_coordinates = \
-        get_vib_harm_freqs_and_eigvecs(coordinates, charges, masses, hess, True, 0)
+    vib_energies, transformation_matrix, num_coordinates, min_element, max_element = \
+        get_vib_harm_freqs_and_eigvecs(coordinates, charges, masses, hess, True, 0, \
+        harmonic_frequency_limits)
 
     assert np.allclose(ref_vib_energies, vib_energies)
     assert np.allclose(ref_T, transformation_matrix)
     assert ref_num_coordinates == num_coordinates
+    assert ref_min_element == min_element
+    assert ref_max_element == max_element
+
+    harmonic_frequency_limits = [0.00341725, 0.01458027]
+    ref_T = \
+        [[ 3.22981009e-03,  4.17339724e-03, -4.03628914e-04],
+         [-2.86856313e-04,  9.19391442e-04,  5.97284932e-04],
+         [-1.50488540e-02, -1.51582554e-02, -3.00715934e-03],
+         [-1.38024617e-03,  2.89722010e-03, -3.15677757e-04],
+         [-2.92412422e-03,  3.13500922e-03,  6.51580245e-04],
+         [ 1.50507102e-02, -1.51597004e-02,  3.00626300e-03],
+         [ 1.11679665e-03,  1.44609639e-04, -1.70604122e-04],
+         [ 7.77635495e-04, -7.65522406e-04, -1.48224530e-04],
+         [-6.03883287e-04,  9.55520058e-04,  4.06140663e-03],
+         [-1.23333598e-03, -5.90122786e-04,  2.15926979e-04],
+         [-5.75314541e-04,  5.10058319e-04,  6.95346751e-05],
+         [ 6.03766333e-04,  9.54786678e-04, -4.06135015e-03]]
+
+    ref_vib_energies = [0.008117022153354516, 0.007240632902872262, 0.00677517594096139]
+    ref_min_element = 2
+    ref_max_element = 4
+
+    vib_energies, transformation_matrix, num_coordinates, min_element, max_element = \
+        get_vib_harm_freqs_and_eigvecs(coordinates, charges, masses, hess, True, 0, \
+        harmonic_frequency_limits)
+
+    assert np.allclose(ref_vib_energies, vib_energies)
+    assert np.allclose(ref_T, transformation_matrix)
+    assert ref_num_coordinates == num_coordinates
+    assert ref_min_element == min_element
+    assert ref_max_element == max_element
 
     # No outproj
 
+    harmonic_frequency_limits = 'Keep all'
     ref_T = \
         [[ 1.53222364e-02,  1.53670155e-02, -3.22975982e-03, -4.17335205e-03,
            4.03681984e-04, -8.51675722e-04, -2.74560138e-03,  4.55906564e-03,
@@ -309,13 +336,19 @@ def test_get_vib_harm_freqs_and_eigvecs():
                         8.45233427956114e-08, (1.0077399472433052e-23+1.645764228420689e-07j), \
                         (3.1088767339073406e-21+5.077181006102105e-05j)]
 
-    vib_energies, transformation_matrix, num_coordinates = \
-        get_vib_harm_freqs_and_eigvecs(coordinates, charges, masses, hess, False, 0)
+    ref_min_element = 0
+    ref_max_element = 11
+
+    vib_energies, transformation_matrix, num_coordinates, min_element, max_element = \
+        get_vib_harm_freqs_and_eigvecs(coordinates, charges, masses, hess, False, 0, \
+        harmonic_frequency_limits)
 
 
     assert np.allclose(ref_vib_energies, vib_energies)
     assert np.allclose(ref_T, transformation_matrix)
     assert ref_num_coordinates == num_coordinates
+    assert ref_min_element == min_element
+    assert ref_max_element == max_element
 
     # Linear molecule (CO2)
     coordinates = [[-5.73169685, -0.11606755, -0.0], [-3.58625798, -0.03208891, -0.0], \
@@ -353,57 +386,179 @@ def test_get_vib_harm_freqs_and_eigvecs():
 
     ref_vib_energies = [0.01168413, 0.00688573, 0.0035219,  0.00352189]
 
-    ref_T = [[-5.76138140e-03,  4.51914042e-09,  9.89553346e-14, -2.25536758e-04,
-               2.44638062e-03,  2.97137698e-03,  2.97137698e-03,  3.23829033e-03,
-               3.23829033e-03],
-             [-2.25536758e-04,  4.51764187e-08, -2.52811545e-12,  5.76138140e-03,
-               4.39406391e-04,  6.42672128e-04,  6.42672128e-04, -3.07561126e-04,
-              -3.07561126e-04],
-             [ 1.11370401e-17, -1.96228205e-17, -5.76579417e-03, -3.16526184e-12,
-              -1.05461341e-03, -1.29138409e-03, -1.29138409e-03, -3.25963710e-06,
-              -3.25963710e-06],
-             [ 2.16120973e-03,  4.13791220e-03, -3.71180195e-14,  8.45709149e-05,
-               2.53984913e-03,  2.98952229e-03,  2.98952229e-03,  3.23532865e-03,
-               3.23532865e-03],
-             [ 8.45947082e-05,  1.61969458e-04,  9.48345710e-13, -2.16120647e-03,
-              -1.94847447e-03,  1.79105965e-04,  1.79105965e-04, -2.31897781e-04,
-              -2.31897781e-04],
-             [-4.17742129e-18,  6.88938217e-18,  2.16308141e-03,  1.18747146e-12,
-              -2.24337865e-03, -2.31143387e-03, -2.31143387e-03, -3.38842799e-06,
-              -3.38842799e-06],
-             [ 2.16120004e-03, -4.13791559e-03, -3.71218328e-14,  8.46354294e-05,
-               2.35289298e-03,  2.95322795e-03,  2.95322795e-03,  3.24125261e-03,
-               3.24125261e-03],
-             [ 8.46116361e-05, -1.62003351e-04,  9.48345007e-13, -2.16120330e-03,
-               2.82728722e-03,  1.10623828e-03,  1.10623828e-03, -3.83224469e-04,
-              -3.83224469e-04],
-             [-4.17657299e-18,  6.87753819e-18,  2.16263898e-03,  1.18722860e-12,
-               1.34395024e-04, -2.71125631e-04, -2.71125631e-04, -3.13081986e-06,
-              -3.13081986e-06]]
+    ref_T = [[-5.76138140e-03,  4.51914042e-09,  9.89553346e-14, -2.25536758e-04],
+             [-2.25536758e-04,  4.51764187e-08, -2.52811545e-12,  5.76138140e-03],
+             [ 1.11370401e-17, -1.96228205e-17, -5.76579417e-03, -3.16526184e-12],
+             [ 2.16120973e-03,  4.13791220e-03, -3.71180195e-14,  8.45709149e-05],
+             [ 8.45947082e-05,  1.61969458e-04,  9.48345710e-13, -2.16120647e-03],
+             [-4.17742129e-18,  6.88938217e-18,  2.16308141e-03,  1.18747146e-12],
+             [ 2.16120004e-03, -4.13791559e-03, -3.71218328e-14,  8.46354294e-05],
+             [ 8.46116361e-05, -1.62003351e-04,  9.48345007e-13, -2.16120330e-03],
+             [-4.17657299e-18,  6.87753819e-18,  2.16263898e-03,  1.18722860e-12]]
 
     ref_num_coordinates = 9
+    ref_max_element = 3
 
-    vib_energies, transformation_matrix, num_coordinates = \
-        get_vib_harm_freqs_and_eigvecs(coordinates, charges, masses, CO2_hess, True, 0)
+    vib_energies, transformation_matrix, num_coordinates, min_element, max_element = \
+        get_vib_harm_freqs_and_eigvecs(coordinates, charges, masses, CO2_hess, True, 0, \
+        harmonic_frequency_limits)
 
     assert np.allclose(ref_vib_energies, vib_energies)
     assert np.allclose(ref_T, transformation_matrix)
     assert ref_num_coordinates == num_coordinates
+    assert ref_min_element == min_element
+    assert ref_max_element == max_element
 
 
-def test_get_vibrational_w():
+def test_cut_at_harmonic_frequency_limits():
+
+    T = [[-1.53222357e-02, -1.53669888e-02,  3.22981009e-03,
+           4.17339724e-03, -4.03628914e-04, -8.54362528e-04],
+         [-4.88454587e-04, -6.26090972e-04, -2.86856313e-04,
+           9.19391442e-04,  5.97284932e-04,  1.58823715e-02],
+         [-4.54192140e-03, -4.36068019e-03, -1.50488540e-02,
+          -1.51582554e-02, -3.00715934e-03,  3.65915208e-04],
+         [-8.12088720e-03,  8.23711286e-03, -1.38024617e-03,
+           2.89722010e-03, -3.15677757e-04, -1.33095828e-02],
+         [-1.30330770e-02,  1.29622276e-02, -2.92412422e-03,
+           3.13500922e-03,  6.51580245e-04,  8.70769872e-03],
+         [-4.54112240e-03,  4.34618794e-03,  1.50507102e-02,
+          -1.51597004e-02,  3.00626300e-03, -3.80756305e-04],
+         [ 5.11949879e-04, -5.26040879e-04,  1.11679665e-03,
+           1.44609639e-04, -1.70604122e-04,  9.86304146e-04],
+         [ 8.20763107e-04, -8.20829892e-04,  7.77635495e-04,
+          -7.65522406e-04, -1.48224530e-04, -4.63682059e-04],
+         [ 2.86187714e-04, -3.45501456e-04, -6.03883287e-04,
+           9.55520058e-04,  4.06140663e-03, -1.10939371e-04],
+         [ 9.65179904e-04,  9.75287860e-04, -1.23333598e-03,
+          -5.90122786e-04,  2.15926979e-04, -9.38468746e-05],
+         [ 3.12162589e-05,  4.35411782e-05, -5.75314541e-04,
+           5.10058319e-04,  6.95346751e-05, -1.08571583e-03],
+         [ 2.86126589e-04,  3.46414599e-04,  6.03766333e-04,
+           9.54786678e-04, -4.06135015e-03,  1.11874495e-04]]
+
+    w = [0.018901853587738812, 0.018867981781313763, 0.008117022142471952, \
+         0.007240632909554118, 0.006775175945822372, 0.0008338069614039414]
+
+    ref_cut_T = \
+        [[ 3.22981009e-03,  4.17339724e-03, -4.03628914e-04],
+         [-2.86856313e-04,  9.19391442e-04,  5.97284932e-04],
+         [-1.50488540e-02, -1.51582554e-02, -3.00715934e-03],
+         [-1.38024617e-03,  2.89722010e-03, -3.15677757e-04],
+         [-2.92412422e-03,  3.13500922e-03,  6.51580245e-04],
+         [ 1.50507102e-02, -1.51597004e-02,  3.00626300e-03],
+         [ 1.11679665e-03,  1.44609639e-04, -1.70604122e-04],
+         [ 7.77635495e-04, -7.65522406e-04, -1.48224530e-04],
+         [-6.03883287e-04,  9.55520058e-04,  4.06140663e-03],
+         [-1.23333598e-03, -5.90122786e-04,  2.15926979e-04],
+         [-5.75314541e-04,  5.10058319e-04,  6.95346751e-05],
+         [ 6.03766333e-04,  9.54786678e-04, -4.06135015e-03]]
+
+    ref_cut_w = [0.00811702, 0.00724063, 0.00677518]
+    harmonic_frequency_limits = [0.00341725, 0.01458027]
+    ref_min_element = 2
+    ref_max_element = 4
+
+    cut_w, cut_T, min_element, max_element = \
+        cut_at_harmonic_frequency_limits(w, T, 12, harmonic_frequency_limits)
+
+    assert np.allclose(ref_cut_w, cut_w)
+    assert np.allclose(ref_cut_T, cut_T)
+    assert ref_min_element == min_element
+    assert ref_max_element == max_element
+
+    ref_min_element = 0
+    ref_max_element = 5
+    harmonic_frequency_limits = [0.0001, 0.02]
+
+    cut_w, cut_T, min_element, max_element = \
+        cut_at_harmonic_frequency_limits(w, T, 12, harmonic_frequency_limits)
+
+    assert np.allclose(w, cut_w)
+    assert np.allclose(T, cut_T)
+    assert ref_min_element == min_element
+    assert ref_max_element == max_element
+
+
+def test_get_vibrational_w_and_T():
+
+    T = \
+        [[-1.53222357e-02, -1.53669888e-02,  3.22981009e-03,  4.17339724e-03, \
+          -4.03628914e-04, -8.54362528e-04,  1.13488075e-03, -2.88616863e-04, \
+          -3.77606108e-04, -1.62362393e-03, -1.62362393e-03,  5.14035877e-04], \
+         [-4.88454587e-04, -6.26090972e-04, -2.86856313e-04,  9.19391442e-04, \
+           5.97284932e-04,  1.58823715e-02, -1.14146847e-03,  7.96520914e-03, \
+           3.28688007e-03, -1.64709234e-03, -1.64709234e-03, -9.62826828e-03], \
+         [-4.54192140e-03, -4.36068019e-03, -1.50488540e-02, -1.51582554e-02, \
+          -3.00715934e-03,  3.65915208e-04, -1.96142805e-03, -2.50207663e-04, \
+          -2.48190436e-05,  3.54138948e-03,  3.54138948e-03, -4.62509663e-06], \
+         [-8.12088720e-03,  8.23711286e-03, -1.38024617e-03,  2.89722010e-03, \
+          -3.15677757e-04, -1.33095828e-02, -4.84150203e-03,  6.19763680e-03, \
+          -2.44347259e-03, -1.40658966e-03, -1.40658966e-03, -9.84941656e-03], \
+         [-1.30330770e-02,  1.29622276e-02, -2.92412422e-03,  3.13500922e-03, \
+           6.51580245e-04,  8.70769872e-03, -4.48933861e-03, -6.19650723e-04, \
+           1.74382574e-03,  6.45440786e-04,  6.45440786e-04,  8.99006010e-03], \
+         [-4.54112240e-03,  4.34618794e-03,  1.50507102e-02, -1.51597004e-02, \
+           3.00626300e-03, -3.80756305e-04,  3.45825375e-03, -1.30143133e-03, \
+           2.00114363e-03,  2.48623031e-03,  2.48623031e-03, -2.63082451e-04], \
+         [ 5.11949879e-04, -5.26040879e-04,  1.11679665e-03,  1.44609639e-04, \
+          -1.70604122e-04,  9.86304146e-04, -1.50682473e-03, -2.55382512e-03, \
+           2.03048197e-04, -9.73793860e-04, -9.73793860e-04, -1.59801919e-03], \
+         [ 8.20763107e-04, -8.20829892e-04,  7.77635495e-04, -7.65522406e-04, \
+          -1.48224530e-04, -4.63682059e-04, -5.10657338e-03,  4.11025264e-03, \
+           9.19617398e-04,  1.06259271e-04,  1.06259271e-04,  3.28095483e-03], \
+         [ 2.86187714e-04, -3.45501456e-04, -6.03883287e-04,  9.55520058e-04, \
+           4.06140663e-03, -1.10939371e-04, -7.45728136e-04,  7.80849642e-04, \
+          -3.73049118e-04,  3.26180135e-03,  3.26180135e-03,  1.36954278e-03], \
+         [ 9.65179904e-04,  9.75287860e-04, -1.23333598e-03, -5.90122786e-04, \
+           2.15926979e-04, -9.38468746e-05,  5.54270900e-04, -2.53545305e-04, \
+          -4.05103152e-04, -1.53831645e-03, -1.53831645e-03, -2.06526629e-04], \
+         [ 3.12162589e-05,  4.35411782e-05, -5.75314541e-04,  5.10058319e-04, \
+           6.95346751e-05, -1.08571583e-03,  1.06062494e-03, -1.78354784e-03, \
+           5.61812796e-03, -8.09242269e-04, -8.09242269e-04,  4.20426292e-04], \
+         [ 2.86126589e-04,  3.46414599e-04,  6.03766333e-04,  9.54786678e-04, \
+          -4.06135015e-03,  1.11874495e-04, -2.34995409e-04,  6.84086724e-04, \
+          -1.83586994e-04,  3.16228875e-03,  3.16228875e-03,  1.34778770e-03]]
 
     w = [0.018901853587738812, 0.018867981781313763, 0.008117022142471952, 0.007240632909554118, \
          0.006775175945822372, 0.0008338069614039414, 9.795831917075847e-11, 9.06072465808631e-12, \
          9.06072465808631e-12, (3.468545572026408e-27+5.664564794422922e-11j), \
-        (3.468545572026408e-27+5.664564794422922e-11j), (4.344353699553894e-27+7.094868010235445e-11j)]
+        (3.468545572026408e-27+5.664564794422922e-11j), \
+        (4.344353699553894e-27+7.094868010235445e-11j)]
+
+    ref_vib_T = \
+        [[-1.53222357e-02, -1.53669888e-02,  3.22981009e-03,
+           4.17339724e-03, -4.03628914e-04, -8.54362528e-04],
+         [-4.88454587e-04, -6.26090972e-04, -2.86856313e-04,
+           9.19391442e-04,  5.97284932e-04,  1.58823715e-02],
+         [-4.54192140e-03, -4.36068019e-03, -1.50488540e-02,
+          -1.51582554e-02, -3.00715934e-03,  3.65915208e-04],
+         [-8.12088720e-03,  8.23711286e-03, -1.38024617e-03,
+           2.89722010e-03, -3.15677757e-04, -1.33095828e-02],
+         [-1.30330770e-02,  1.29622276e-02, -2.92412422e-03,
+           3.13500922e-03,  6.51580245e-04,  8.70769872e-03],
+         [-4.54112240e-03,  4.34618794e-03,  1.50507102e-02,
+          -1.51597004e-02,  3.00626300e-03, -3.80756305e-04],
+         [ 5.11949879e-04, -5.26040879e-04,  1.11679665e-03,
+           1.44609639e-04, -1.70604122e-04,  9.86304146e-04],
+         [ 8.20763107e-04, -8.20829892e-04,  7.77635495e-04,
+          -7.65522406e-04, -1.48224530e-04, -4.63682059e-04],
+         [ 2.86187714e-04, -3.45501456e-04, -6.03883287e-04,
+           9.55520058e-04,  4.06140663e-03, -1.10939371e-04],
+         [ 9.65179904e-04,  9.75287860e-04, -1.23333598e-03,
+          -5.90122786e-04,  2.15926979e-04, -9.38468746e-05],
+         [ 3.12162589e-05,  4.35411782e-05, -5.75314541e-04,
+           5.10058319e-04,  6.95346751e-05, -1.08571583e-03],
+         [ 2.86126589e-04,  3.46414599e-04,  6.03766333e-04,
+           9.54786678e-04, -4.06135015e-03,  1.11874495e-04]]
 
     ref_vib_w = [0.018901853587738812, 0.018867981781313763, 0.008117022142471952, \
                  0.007240632909554118, 0.006775175945822372, 0.0008338069614039414]
 
-    vib_w = get_vibrational_w(False, 12, w, True, 0)
+    vib_w, vib_T = get_vibrational_w_and_T(False, 12, w, T, True, 0)
 
     assert np.allclose(ref_vib_w, vib_w)
+    assert np.allclose(ref_vib_T, vib_T)
 
     # No outprojection
 
@@ -414,6 +569,7 @@ def test_get_vibrational_w():
                  9.06072466e-12+0.00000000e+00j, 3.46854557e-27+5.66456479e-11j, \
                  3.46854557e-27+5.66456479e-11j, 4.34435370e-27+7.09486801e-11j]
 
-    vib_w = get_vibrational_w(False, 12, w, False, 0)
+    vib_w, vib_T = get_vibrational_w_and_T(False, 12, w, T, False, 0)
 
     assert np.allclose(ref_vib_w, vib_w)
+    assert np.allclose(T, vib_T)
