@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -33,60 +33,61 @@ import copy
 # Simple function to multiply elements in list
 def list_product_int(l):
 
-	v = 1
+    v = 1
 
-	for i in l:
-		v *= i
+    for i in l:
+        v *= i
 
-	return v
+    return v
 
 
 # Recursive routine to transform one rank of geometric differentiation from Cartesian to normal mode
 # basis. To be called from transform_cartesian_to_normal
-def transform_cartesian_to_normal_one_rank(w, rank_geo, c, offset, offset_b, ind_w, num_coordinates, \
-                                           num_vib_coordinates, num_nongeo_components, A, B, T, act):
-	
-	if (c > 0):
-		for i in range(num_coordinates):
+def transform_cartesian_to_normal_one_rank(w, rank_geo, c, offset, offset_b, ind_w, \
+                                        num_coordinates, min_element, max_element, \
+                                        num_nongeo_components, A, B, T, act):
 
-			if ((c <= w[0])):
-				if ((i + 1) > num_vib_coordinates):
-					act = 0
-				if (c == min(w)):
-					ind_w = i
+    if (c > 0):
+        for i in range(num_coordinates):
 
-			transform_cartesian_to_normal_one_rank(w, rank_geo, c-1, offset, offset_b, ind_w, \
-                                                   num_coordinates, num_vib_coordinates, \
-                                                   num_nongeo_components, A, B, T, act)
+            if ((c <= w[0])):
+                if (i > max_element):
+                    act = 0
+                if (c == min(w)):
+                    ind_w = i
 
-			if (c > min(w)):
-				act = 1
+            transform_cartesian_to_normal_one_rank(w, rank_geo, c-1, offset, offset_b, ind_w, \
+                                                num_coordinates, min_element, max_element, \
+                                                num_nongeo_components, A, B, T, act)
 
-			if not (c in w):
-				offset[0] += int((num_nongeo_components) * num_coordinates**((c - 1)))
+            if (c > min(w)):
+                act = 1
 
-			offset_b[0] += int((num_nongeo_components) * num_coordinates**((c - 1)))
+            if not (c in w):
+                offset[0] += int((num_nongeo_components) * num_coordinates**((c - 1)))
 
-		if not(c in w):
-			offset[0] -= int((num_coordinates * num_nongeo_components) * num_coordinates**((c - 1)))
+            offset_b[0] += int((num_nongeo_components) * num_coordinates**((c - 1)))
 
-		offset_b[0] -= int((num_coordinates * num_nongeo_components) * num_coordinates**((c - 1)))
+        if not(c in w):
+            offset[0] -= int((num_coordinates * num_nongeo_components) * num_coordinates**((c - 1)))
 
-	else:
-		if (act):
+        offset_b[0] -= int((num_coordinates * num_nongeo_components) * num_coordinates**((c - 1)))
 
-			tmp = np.zeros((int(num_nongeo_components)))
-			offset_n = offset[0]
+    else:
+        if (act and not (ind_w < min_element)):
 
-			for j in range(num_coordinates):
-				for i in range(int(num_nongeo_components)):
-					tmp[i] += A[offset_n + i] * T[j][ind_w]
+            tmp = np.zeros((int(num_nongeo_components)))
+            offset_n = offset[0]
 
-				offset_n += int(num_nongeo_components * num_coordinates**((min(w) - 1)))
+            for j in range(num_coordinates):
+                for i in range(int(num_nongeo_components)):
+                    tmp[i] += A[offset_n + i] * T[j][ind_w - min_element]
 
-			B[offset_b[0]:offset_b[0] + int(num_nongeo_components)] = tmp[:]
+                offset_n += int(num_nongeo_components * num_coordinates**((min(w) - 1)))
 
-	return
+            B[offset_b[0]:offset_b[0] + int(num_nongeo_components)] = tmp[:]
+
+    return
 
 
 # Routine to transform a tensor A from Cartesian to normal mode basis
@@ -102,32 +103,33 @@ def transform_cartesian_to_normal_one_rank(w, rank_geo, c, offset, offset_b, ind
 # T is a transformation matrix of size (num_coordinates, num_vib_coordinates) (it can also be
 # (num_coordinates, num_coordinates) but only the first num_vib_coordinates components of the second rank
 # should be used) expressing the normal modes in terms of Cartesian displacements
-def transform_cartesian_to_normal(A, dims, rank_geo, num_coordinates, num_vib_coordinates, T):
-	
-	# Collapse array to be reshaped
-	tmp = np.reshape(A, list_product_int(dims))
-	A = tmp
-	
-	B = np.zeros(A.shape)
-	
-	num_nongeo_components = list_product_int(dims) / (num_coordinates**rank_geo)
-	ind_w = 0
+def transform_cartesian_to_normal(A, dims, rank_geo, num_coordinates, min_element, max_element, T):
 
-	# Go through ranks of geometric differentiation and transform
-	for i in range(rank_geo):
+    num_vib_coordinates = max_element - min_element + 1
+    # Collapse array to be reshaped
+    tmp = np.reshape(A, list_product_int(dims))
+    A = tmp
 
-		offset = [0]
-		offset_b = [0]
-		w = [i + 1]
+    B = np.zeros(A.shape)
 
-		# Call recursive routine to transform one rank
-		transform_cartesian_to_normal_one_rank(w, rank_geo, rank_geo, offset, offset_b, ind_w, \
-                                               num_coordinates, num_vib_coordinates, \
-                                               num_nongeo_components,  A, B, T, 1)
+    num_nongeo_components = list_product_int(dims) / (num_coordinates**rank_geo)
+    ind_w = 0
 
-		A = copy.deepcopy(B)
-		B = 0.0* B
+    # Go through ranks of geometric differentiation and transform
+    for i in range(rank_geo):
 
-	A = A.reshape(dims)
+        offset = [0]
+        offset_b = [0]
+        w = [i + 1]
 
-	return A
+        # Call recursive routine to transform one rank
+        transform_cartesian_to_normal_one_rank(w, rank_geo, rank_geo, offset, offset_b, ind_w, \
+                                            num_coordinates, min_element, max_element, \
+                                            num_nongeo_components,  A, B, T, 1)
+
+        A = copy.deepcopy(B)
+        B = 0.0* B
+
+    A = A.reshape(dims)
+
+    return A
