@@ -1,4 +1,4 @@
-# SpectroscPy 0.2.0
+# SpectroscPy 0.3.0
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -237,7 +237,8 @@ def project_out_transl_and_rot(num_vib_modes, hess, coords, is_linear):
 
 # Take molecule filename and (NumPy) Hessian array and return number of Cartesian coordinates,
 # whether the molecule is linear, vibrational frequencies and nm transformation matrix
-def get_vib_harm_freqs_and_eigvecs(coords, charges, masses, hess, outproj, print_level):
+def get_vib_harm_freqs_and_eigvecs(coords, charges, masses, hess, outproj, print_level, \
+                                   harmonic_frequency_limits):
 
     amu_au_sqrt = (electron_mass/one_twelfth_carbon)**0.5
     is_linear = mol_is_linear(coords)
@@ -275,38 +276,73 @@ def get_vib_harm_freqs_and_eigvecs(coords, charges, masses, hess, outproj, print
 
     w = [float(i)**0.5 for i in w.real]
 
-    vib_w = get_vibrational_w(is_linear, 3*len(coords), w, outproj, print_level)
+    vib_w, vib_T = get_vibrational_w_and_T(is_linear, 3*len(coords), w, T.real, outproj, print_level)
 
-    return vib_w, T.real, 3*len(coords)
+    if (harmonic_frequency_limits == 'Keep all'):
+        cut_w = np.copy(vib_w)
+        cut_T = np.copy(vib_T)
+        min_element = 0
+        max_element = len(vib_w) - 1
+    else:
+        cut_w, cut_T, min_element, max_element = \
+            cut_at_harmonic_frequency_limits(vib_w, vib_T, 3*len(coords), harmonic_frequency_limits)
+
+    return cut_w, cut_T, 3*len(coords), min_element, max_element
 
 
-def get_vibrational_w(is_linear, num_coordinates, w, outproj, print_level):
+def cut_at_harmonic_frequency_limits(w, T, num_coordinates, harmonic_frequency_limits):
+
+    num_valid_modes = 0
+    for i in range(len(w)):
+        if (w[i] > harmonic_frequency_limits[0] and w[i] < harmonic_frequency_limits[1]):
+            num_valid_modes = num_valid_modes + 1
+
+    cut_w = np.zeros(num_valid_modes)
+    cut_T = np.zeros((num_coordinates, num_valid_modes))
+
+    k = 0
+    min_element = len(w)
+    max_element = 0
+    for i in range(len(w)):
+        if (w[i] > harmonic_frequency_limits[0] and w[i] < harmonic_frequency_limits[1]):
+            if (i < min_element):
+                min_element = i
+            if (i > max_element):
+                max_element = i
+
+            cut_w[k] = w[i]
+            for j in range(num_coordinates):
+                cut_T[j][k] = T[j][i]
+
+            k = k + 1
+
+    return cut_w, cut_T, min_element, max_element
+
+
+def get_vibrational_w_and_T(is_linear, num_coordinates, w, T, outproj, print_level):
 
     if (is_linear):
         vib_degrees_of_freedom = num_coordinates - 5
     else:
         vib_degrees_of_freedom = num_coordinates - 6
 
-    if (len(w) == vib_degrees_of_freedom):
+    if (outproj):
         if (print_level > 0):
-            print('Only vibrational frequencies were calcuated')
+            print('Number of vibrational degrees of freedom: ', vib_degrees_of_freedom)
+            print('Number of frequencies calculated: ', len(w))
+            print('Will only include the vibrational frequencies, cutting the rotational' \
+                    'and translational degrees of freedom')
 
-        vib_w = w
+        vib_w = np.zeros(vib_degrees_of_freedom)
+        vib_T = np.zeros((num_coordinates, vib_degrees_of_freedom))
 
+        for i in range(vib_degrees_of_freedom):
+            vib_w[i] = w[i]
+            for j in range(num_coordinates):
+                vib_T[j][i] = T[j][i]
     else:
-        if (outproj):
-            if (print_level > 0):
-                print('Number of vibrational degrees of freedom: ', vib_degrees_of_freedom)
-                print('Number of frequencies calculated: ', len(w))
-                print('Will only include the vibrational frequencies, cutting the rotational' \
-                      'and translational degrees of freedom')
-
-            vib_w = np.zeros(vib_degrees_of_freedom)
-
-            for i in range(vib_degrees_of_freedom):
-                vib_w[i] = w[i]
-        else:
-            vib_w = np.copy(w)
+        vib_w = np.copy(w)
+        vib_T = np.copy(T)
 
     # Look at this for the unproj case once actual environments can be used
     if (outproj):
@@ -318,4 +354,4 @@ def get_vibrational_w(is_linear, num_coordinates, w, outproj, print_level):
                 print('minima?')
                 exit()
 
-    return vib_w
+    return vib_w, vib_T
